@@ -1073,7 +1073,7 @@ DrawFace(ModeInfo * mi, int color, XPoint * cubepts,
 		gc = ap->stippledGC;
 	}
 	if (!ap->wireframe)
-		XFillPolygon(display, ap->dbuf, gc, facepts, 4,
+		XFillPolygon(display, (Drawable) ap->dbuf, gc, facepts, 4,
 			Convex, CoordModeOrigin);
 	gc = MI_GC(mi);
 	if (!ap->wireframe) {
@@ -1083,7 +1083,7 @@ DrawFace(ModeInfo * mi, int color, XPoint * cubepts,
 			XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
 		}
 	}
-	XDrawLines(display, ap->dbuf, gc, facepts, 5, CoordModeOrigin);
+	XDrawLines(display, (Drawable) ap->dbuf, gc, facepts, 5, CoordModeOrigin);
 }
 
 static void
@@ -1135,7 +1135,7 @@ DrawEyes(ModeInfo * mi, int color, XPoint * cubepts,
 		gc = ap->stippledGC;
 	}
 	if (!ap->wireframe)
-		XFillPolygon(display, ap->dbuf, gc, facepts, 4,
+		XFillPolygon(display, (Drawable) ap->dbuf, gc, facepts, 4,
 			Convex, CoordModeOrigin);
 	gc = MI_GC(mi);
 	if (!ap->wireframe) {
@@ -1145,7 +1145,8 @@ DrawEyes(ModeInfo * mi, int color, XPoint * cubepts,
 			XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
 		}
 	}
-	XDrawLines(display, ap->dbuf, gc, facepts, 5, CoordModeOrigin);
+	XDrawLines(display, (Drawable) ap->dbuf, gc, facepts, 5,
+		CoordModeOrigin);
 }
 
 #define LEN 0.45
@@ -1261,7 +1262,7 @@ DrawScreen(ModeInfo * mi)
 	SortList(ap);
 
 	XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
-	XFillRectangle(display, ap->dbuf, gc, 0, 0,
+	XFillRectangle(display, (Drawable) ap->dbuf, gc, 0, 0,
 		ap->width, ap->height);
 
 	/* Erase dead cubes */
@@ -1293,14 +1294,14 @@ DrawScreen(ModeInfo * mi)
 				16 + ap->labelOffsetX,
 				16 + ap->labelOffsetY + FONT_HEIGHT,
 				ap->ruleString, strlen(ap->ruleString)); */
-			XDrawString(display, ap->dbuf, gc,
+			XDrawString(display, (Drawable) ap->dbuf, gc,
 				16 + ap->labelOffsetX, MI_HEIGHT(mi) - 16 -
 				ap->labelOffsetY - FONT_HEIGHT / 2,
 				ap->ruleString, strlen(ap->ruleString));
 		}
 	}
 	XFlush(display);
-	XCopyArea(display, ap->dbuf, MI_WINDOW(mi), gc,
+	XCopyArea(display, (Drawable) ap->dbuf, MI_WINDOW(mi), gc,
 		0, 0, ap->width, ap->height, 0, 0);
 #if 0
 	{
@@ -1319,9 +1320,19 @@ DrawScreen(ModeInfo * mi)
 static void
 free_ant3d(Display *display, antfarm3dstruct *ap)
 {
+	int shade;
+
 	if (ap->eraserhead.next != NULL) {
 		End3D(ap);
 	}
+	if (ap->stippledGC != None) {
+		XFreeGC(display, ap->stippledGC);
+		ap->stippledGC = None;
+	}
+	for (shade = 0; shade < ap->init_bits; shade++) {
+		XFreePixmap(display, ap->pixmaps[shade]);
+	}
+	ap->init_bits = 0;
 	if (ap->dbuf != None) {
 		XFreePixmap(display, ap->dbuf);
 		ap->dbuf = None;
