@@ -111,8 +111,6 @@ static const char sccsid[] = "@(#)crystal.c	5.08 2003/04/28 xlockmore";
 #define DEF_MAXSIZE "False"
 #define DEF_CYCLE "True"
 
-#define min(a,b) ((a) <= (b) ? (a) : (b))
-
 static int  nx, ny;
 
 static Bool unit_cell, grid_cell, centre, maxsize, cycle_p;
@@ -630,7 +628,7 @@ init_crystal(ModeInfo * mi)
 	cryst = &crystals[MI_SCREEN(mi)];
 	cryst->mi = mi;
 
-	if (!cryst->gc) {
+	if (cryst->gc == None) {
 		if (MI_IS_INSTALL(mi) && MI_NPIXELS(mi) > 2) {
 			XColor      color;
 
@@ -694,8 +692,8 @@ init_crystal(ModeInfo * mi)
 	}
 	cryst->win_width = MAX(MI_WIDTH(mi) + 1, MIN_CELL);
 	cryst->win_height = MAX(MI_HEIGHT(mi) + 1, MIN_CELL);
-	cell_min = min(cryst->win_width / 2 + 1, MIN_CELL);
-	cell_min = min(cell_min, cryst->win_height / 2 + 1);
+	cell_min = MIN(cryst->win_width / 2 + 1, MIN_CELL);
+	cell_min = MIN(cell_min, cryst->win_height / 2 + 1);
 	cryst->planegroup = NRAND(17);
         cryst->invert = NRAND(2);
 	if (MI_IS_VERBOSE(mi))
@@ -758,7 +756,7 @@ init_crystal(ModeInfo * mi)
 				cryst->b = cryst->win_height;
 				cryst->a = cryst->win_width;
 			} else {
-				cryst->b = min(cryst->win_height, cryst->win_width);
+				cryst->b = MIN(cryst->win_height, cryst->win_width);
 				cryst->a = cryst->b;
 			}
 		} else {
@@ -805,7 +803,7 @@ init_crystal(ModeInfo * mi)
 		}
 	}
 
-	size_atom = min((int) ((float) (cryst->a) / 40.) + 1,
+	size_atom = MIN((int) ((float) (cryst->a) / 40.) + 1,
 			(int) ((float) (cryst->b) / 40.) + 1);
 	if (MI_SIZE(mi) < size_atom) {
 		if (MI_SIZE(mi) < -size_atom)
