@@ -492,7 +492,6 @@ init_demon(ModeInfo * mi)
 
 	dp->width = MI_WIDTH(mi);
 	dp->height = MI_HEIGHT(mi);
-
 	if (dp->neighbors == 6) {
 		int         nccols, ncrows, i;
 
@@ -517,7 +516,7 @@ init_demon(ModeInfo * mi)
 		dp->ncols = nccols / 2;
 		dp->nrows = 2 * (ncrows / 4);
 		dp->xb = (dp->width - dp->xs * nccols) / 2 + dp->xs / 2;
-		dp->yb = (dp->height - dp->ys * (ncrows / 2) * 2) / 2 + dp->ys - 2;
+		dp->yb = (dp->height - dp->ys * (ncrows / 2) * 2) / 2 + dp->ys / 4;
 		for (i = 0; i < 6; i++) {
 			dp->shape.hexagon[i].x = (dp->xs - 1) * hexagonUnit[i].x;
 			dp->shape.hexagon[i].y = ((dp->ys - 1) * hexagonUnit[i].y / 2) * 4 / 3;
