@@ -78,11 +78,11 @@ static XrmOptionDescRec opts[] = {
 };
 
 static argtype vars[] = {
-  {(caddr_t *) &max_depth, (char *) "maxdepth", (char *) "MaxDepth",
+  {(void *) &max_depth, (char *) "maxdepth", (char *) "MaxDepth",
      (char *) "5", t_Int},
-  {(caddr_t *) &speed, (char *) "speed", (char *) "Speed",
+  {(void *) &speed, (char *) "speed", (char *) "Speed",
      (char *) "150", t_Int},
-  {(caddr_t *) &intensity, (char *) "intensity", (char *) "Intensity",
+  {(void *) &intensity, (char *) "intensity", (char *) "Intensity",
      (char *) "2185", t_Int}
 };
 
@@ -232,8 +232,8 @@ triangle (GLfloat x1, GLfloat y1, GLfloat z1,
 {
   if (wireframe_p)
     glBegin (GL_LINE_LOOP);
-  else 
-    { 
+  else
+    {
       do_normal (x1, y1, z1,  x2, y2, z2,  x3, y3, z3);
       glBegin (GL_TRIANGLES);
     }
@@ -338,26 +338,26 @@ compile_gasket(ModeInfo *mi)
   GL_VECTOR   vertex[5];
 
   /* define verticies */
-  vertex[0].x =  0.5; 
+  vertex[0].x =  0.5;
   vertex[0].y = -(1.0/3.0)*sqrt((2.0/3.0));
   vertex[0].z = -sqrt(3.0)/6.0;
 
-  vertex[1].x = -0.5; 
-  vertex[1].y = -(1.0/3.0)*sqrt((2.0/3.0)); 
-  vertex[1].z = -sqrt(3.0)/6.0; 
+  vertex[1].x = -0.5;
+  vertex[1].y = -(1.0/3.0)*sqrt((2.0/3.0));
+  vertex[1].z = -sqrt(3.0)/6.0;
 
-  vertex[2].x = 0.0; 
+  vertex[2].x = 0.0;
   vertex[2].y = (2.0/3.0)*sqrt((2.0/3.0));
-  vertex[2].z = -sqrt(3.0)/6.0; 
+  vertex[2].z = -sqrt(3.0)/6.0;
 
-  vertex[3].x = 0.0; 
-  vertex[3].y = 0.0; 
-  vertex[3].z = sqrt(3.0)/3.0; 
+  vertex[3].x = 0.0;
+  vertex[3].y = 0.0;
+  vertex[3].z = sqrt(3.0)/3.0;
 
   vertex[4].x = 0.0;
-  vertex[4].y = 0.0; 
+  vertex[4].y = 0.0;
   vertex[4].z = 0.0;
-  
+
   four_tetras (vertex, wireframe_p,
                (gp->current_depth < 0
                 ? -gp->current_depth : gp->current_depth));
@@ -369,22 +369,22 @@ draw(ModeInfo *mi)
   Bool wireframe_p = MI_IS_WIREFRAME(mi);
   gasketstruct *gp = &gasket[MI_SCREEN(mi)];
   static int tick = 0;
-  
+
   static GLfloat pos[4] = {1.0, 1.0, 1.0, 0.0};
   static float white[]  = {1.0, 1.0, 1.0, 1.0};
   static float color[]  = {0.0, 0.0, 0.0, 1.0};
 
   glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
 
-  if (!wireframe_p) 
+  if (!wireframe_p)
     {
       glColor4fv (white);
 
-      glLightfv(GL_LIGHT0, GL_POSITION,  pos); 
+      glLightfv(GL_LIGHT0, GL_POSITION,  pos);
 
-      color[0] = gp->colors[gp->ccolor].red  * intens_factor; 
+      color[0] = gp->colors[gp->ccolor].red  * intens_factor;
       color[1] = gp->colors[gp->ccolor].green * intens_factor;
-      color[2] = gp->colors[gp->ccolor].blue * intens_factor;  
+      color[2] = gp->colors[gp->ccolor].blue * intens_factor;
       gp->ccolor++;
       if (gp->ccolor >= gp->ncolors) gp->ccolor = 0;
 
@@ -393,7 +393,7 @@ draw(ModeInfo *mi)
       glShadeModel(GL_SMOOTH);
 
       glEnable(GL_LIGHTING);
-      glEnable(GL_LIGHT0); 
+      glEnable(GL_LIGHT0);
     }
 
   glEnable(GL_DEPTH_TEST);
@@ -465,7 +465,7 @@ reshape_gasket(ModeInfo *mi, int width, int height)
   glMatrixMode(GL_MODELVIEW);
   glLoadIdentity();
   glTranslatef(0.0, 0.0, -15.0);
-  
+
   glClear(GL_COLOR_BUFFER_BIT);
 }
 
