@@ -774,10 +774,10 @@ drawPoly(ModeInfo * mi, Polyinfo * poly, GC gc,
 
 	if (ip->dbuf) {
 		XSetForeground(display, ip->dbuf_gc, MI_BLACK_PIXEL(mi));
-		XFillRectangle(display, ip->dbuf, ip->dbuf_gc, 0, 0,
+		XFillRectangle(display, (Drawable) ip->dbuf, ip->dbuf_gc, 0, 0,
 			polyW + ip->deltaWidth + ip->linewidth,
 			polyH + ip->deltaHeight + ip->linewidth);
-		lwindow = ip->dbuf;
+		lwindow = (Drawable) ip->dbuf;
 		lgc = ip->dbuf_gc;
 	} else {
 		lwindow = window;
@@ -903,7 +903,7 @@ drawPoly(ModeInfo * mi, Polyinfo * poly, GC gc,
 		}
 	}
 	if (ip->dbuf) {
-		XCopyArea(display, ip->dbuf, window, gc, 0, 0,
+		XCopyArea(display, (Drawable) ip->dbuf, window, gc, 0, 0,
 			polyW + 1 + ip->deltaWidth + ip->linewidth,
 			polyH + 1 + ip->deltaHeight + ip->linewidth,
 			currX - ip->deltaWidth / 2 - ip->linewidth / 2,
@@ -962,7 +962,7 @@ init_ico(ModeInfo * mi)
 
 			gcv.fill_style = FillOpaqueStippled;
 			if ((ip->stippledGC = XCreateGC(display, window, GCFillStyle,
-					 &gcv)) == NULL) {
+					 &gcv)) == None) {
 				free_ico(display, ip);
 				return;
 			}
@@ -1045,17 +1045,17 @@ init_ico(ModeInfo * mi)
 
 		if (ip->dbuf_gc != None)
 			XFreeGC(display, ip->dbuf_gc);
-		if ((ip->dbuf_gc = XCreateGC(display, ip->dbuf,
+		if ((ip->dbuf_gc = XCreateGC(display, (Drawable) ip->dbuf,
 				GCForeground | GCBackground | GCGraphicsExposures | GCFunction,
 				&gcv)) == None) {
 			XFreePixmap(display, ip->dbuf);
 			ip->dbuf = None;
 		} else {
-			XFillRectangle(display, ip->dbuf, ip->dbuf_gc,
+			XFillRectangle(display, (Drawable) ip->dbuf, ip->dbuf_gc,
 				0, 0, ip->polyW + ip->deltaWidth + ip->linewidth,
 				ip->polyH + ip->deltaHeight + ip->linewidth);
-			XSetBackground(display, MI_GC(mi), MI_BLACK_PIXEL(mi));
-			XSetFunction(display, MI_GC(mi), GXcopy);
+			/*XSetBackground(display, MI_GC(mi), MI_BLACK_PIXEL(mi));
+			XSetFunction(display, MI_GC(mi), GXcopy);*/
 		}
 	}
 #endif
