@@ -350,6 +350,7 @@ static const struct {
   int       mintrail;                            /* Minimum trail length */
   double    cor;      /* Coefficient of Restitution.  perfect bounce = 1 */
   double    weight;          /* Heavier objects don't get thrown as high */
+  int       sharp;                /* 1 in Chance of making a bloody mess */
 } ObjectDefs[] = {
   { /* Ball */
 	show_ball,
@@ -357,6 +358,7 @@ static const struct {
 	1,
 	0.9,
 	1.0,
+	0
   },
   { /* Club */
 	show_europeanclub,
@@ -364,6 +366,7 @@ static const struct {
 	1,
 	0.55, /* Clubs don't bounce too well */
 	1.0,
+	0
   },
   { /* Torch */
 	show_torch,
@@ -371,6 +374,7 @@ static const struct {
 	20, /* Torches need flames */
 	0.0, /* Torches don't bounce -- fire risk! */
 	1.0,
+	0
   },
   { /* Knife */
 	show_knife,
@@ -378,6 +382,7 @@ static const struct {
 	1,
 	0.0, /* Knives don't bounce */
 	1.0,
+	30
   },
   { /* Ring */
 	show_ring,
@@ -385,6 +390,7 @@ static const struct {
 	1,
 	0.8,
 	1.0,
+	0
   },
   { /* Bowling Ball */
 	show_bball,
@@ -392,6 +398,7 @@ static const struct {
 	1,
 	0.2,
 	5.0,
+	0
   },
 };
 
@@ -1424,10 +1431,10 @@ projectile(jugglestruct *sp)
 	} else {
 	  if (t->posn == '_') { /* Bounce once */
 
-		const int tb = t->start +
+		const int tb = (int) (t->start +
 		  find_bounce(sp, t->y, (double) yf, t->balllink->y,
 					  (double) (t->balllink->start - t->start),
-					  ObjectDefs[t->object->type].cor);
+					  ObjectDefs[t->object->type].cor));
 
 		if(tb < t->start) { /* bounce too hard */
 		  t->posn = '+'; /* Use regular throw */
@@ -1768,7 +1775,7 @@ show_arms(ModeInfo * mi, unsigned long color)
 }
 
 static void
-show_figure(ModeInfo * mi, unsigned long color, Bool init)
+show_figure(ModeInfo * mi, unsigned long color, Bool init, Bool red)
 {
   jugglestruct *sp = &juggles[MI_SCREEN(mi)];
   XPoint p[7];
@@ -1805,6 +1812,12 @@ show_figure(ModeInfo * mi, unsigned long color, Bool init)
 	{ 17, 140}, /* 10 Head2 */
   };
   XPoint a[XtNumber(figure)];
+  int blood;
+  unsigned long redColor = MI_PIXEL(mi, 0);
+
+  if (MI_NPIXELS(mi) <= 2)
+     red = False;
+  blood = (int)red * (NRAND(4) + 1);
 
   /* Translate into device coords */
   for(i = 0; i < XtNumber(figure); i++) {
@@ -1814,30 +1827,34 @@ show_figure(ModeInfo * mi, unsigned long color, Bool init)
 
   XSetLineAttributes(MI_DISPLAY(mi), MI_GC(mi),
 		ARMWIDTH, LineSolid, CapRound, JoinRound);
-  XSetForeground(MI_DISPLAY(mi), MI_GC(mi), color);
 
+  XSetForeground(MI_DISPLAY(mi), MI_GC(mi), (blood == 1) ? redColor : color);
   i = 0; /* Body */
   p[i++] = a[0]; p[i++] = a[1]; p[i++] = a[2];
   p[i++] = a[3]; p[i++] = a[1]; p[i++] = a[4];
   XDrawLines(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 			 p, i, CoordModeOrigin);
 
+  XSetForeground(MI_DISPLAY(mi), MI_GC(mi), (blood == 2) ? redColor : color);
   i = 0;  /* Legs */
   p[i++] = a[7]; p[i++] = a[0]; p[i++] = a[4]; p[i++] = a[8];
   XDrawLines(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 			 p, i, CoordModeOrigin);
 
+  XSetForeground(MI_DISPLAY(mi), MI_GC(mi), (blood == 3) ? redColor : color);
   i = 0;  /* Neck */
   p[i++] = a[5]; p[i++] = a[6];
   XDrawLines(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 			 p, i, CoordModeOrigin);
 
+  XSetForeground(MI_DISPLAY(mi), MI_GC(mi), (blood == 4) ? redColor : color);
   /* Head */
   XDrawArc(MI_DISPLAY(mi), MI_WINDOW(mi), MI_GC(mi),
 		   a[9].x, a[9].y,
 		   a[10].x - a[9].x, a[10].y - a[9].y, 0, 64*360);
   sp->arm[1][LEFT][SHOULDER].x = sp->cx + figure[2].x;
   sp->arm[1][RIGHT][SHOULDER].x = sp->cx + figure[3].x;
+  XSetForeground(MI_DISPLAY(mi), MI_GC(mi), color);
   if(init) {
 	/* Initialise arms */
 	unsigned int i;
@@ -2478,7 +2495,7 @@ change_juggle(ModeInfo * mi)
 	 don't all those special effects. */
   XClearWindow(MI_DISPLAY(mi), MI_WINDOW(mi));
 
-  show_figure(mi, MI_WHITE_PIXEL(mi), True);
+  show_figure(mi, MI_WHITE_PIXEL(mi), True, False);
 
 }
 
@@ -2574,7 +2591,7 @@ init_juggle(ModeInfo * mi)
 		NRAND(patternindex.maxballs - patternindex.minballs);
 	}
 
-	show_figure(mi, MI_WHITE_PIXEL(mi), True); /* Draw figure.  Also discovers
+	show_figure(mi, MI_WHITE_PIXEL(mi), True, False); /* Draw figure.  Also discovers
 							  information about the juggler's
 							  proportions */
 
@@ -2760,13 +2777,28 @@ draw_juggle(ModeInfo * mi)
   cx = wander(sp, sp->time);
   /* Reduce flicker by only permitting movements of more than a pixel */
   if(fabs((sp->cx - cx))*sp->scale >= 2.0 ) {
-	show_figure(mi, MI_BLACK_PIXEL(mi), False);
+	show_figure(mi, MI_BLACK_PIXEL(mi), False, False);
 	sp->cx = cx;
   }
 
-  show_figure(mi, MI_WHITE_PIXEL(mi), False);
-
-  show_arms(mi, MI_WHITE_PIXEL(mi));
+#ifdef BLOOD
+  /* I dunno if I like this or not */
+  o = sp->objects->next;
+  if (MI_NPIXELS(mi) > 2 && ObjectDefs[o->type].sharp != 0 &&
+		!NRAND(ObjectDefs[o->type].sharp)) { /* Knife */
+	if (LRAND() & 1) {
+          show_figure(mi, MI_WHITE_PIXEL(mi), False, True);
+	  show_arms(mi, MI_WHITE_PIXEL(mi));
+	} else {
+          show_figure(mi, MI_WHITE_PIXEL(mi), False, False);
+  	  show_arms(mi, MI_PIXEL(mi, 0)); /* Blood Red */
+       }
+  } else
+#endif
+  {
+        show_figure(mi, MI_WHITE_PIXEL(mi), False, False);
+	show_arms(mi, MI_WHITE_PIXEL(mi));
+  }
 
   /* Draw Objects */
   for (o = sp->objects->next; o != sp->objects; o = o->next) {
