@@ -66,6 +66,7 @@ static const char sccsid[] = "@(#)life3d.c	5.07 2003/01/08 xlockmore";
 #include "xlock.h"		/* in xlockmore distribution */
 
 #endif /* STANDALONE */
+#include "automata.h"
 #include "iostuff.h"
 
 #ifdef MODE_life3d
@@ -133,7 +134,7 @@ ModeSpecOpt life3d_opts =
 {sizeof opts / sizeof opts[0], opts, sizeof vars / sizeof vars[0], vars, desc};
 
 #ifdef USE_MODULES
-ModStruct   life3d_description =
+ModStruct life3d_description =
 {"life3d", "init_life3d", "draw_life3d", "release_life3d",
  "refresh_life3d", "change_life3d", (char *) NULL, &life3d_opts,
  1000000, 35, 85, 1, 64, 1.0, "",
@@ -141,6 +142,11 @@ ModStruct   life3d_description =
 
 #endif
 
+#define LIFE3DBITS(n,w,h)\
+  if ((lp->pixmaps[lp->init_bits]=\
+  XCreatePixmapFromBitmapData(display,window,(char *)n,w,h,1,0,1))==None){\
+  free_life3d(display,lp); return;} else {lp->init_bits++;}
+
 #define ON 0x40
 #define OFF 0
 
@@ -203,7 +209,10 @@ typedef struct {
 	unsigned char *base[BASESIZE];
 	double      A, B, C, F;
 	int         width, height;
+	int         init_bits;
 	unsigned long colors[COLORS];
+	Pixmap      pixmaps[NUMSTIPPLES - 1];
+	GC          stippledGC;
 	double      azm;
 	double      metaAlt, metaAzm, metaDist;
 	CellList   *ptrhead, *ptrend, eraserhead, eraserend;
@@ -227,7 +236,7 @@ codeToPatternedRule(paramstruct param)
 
 	for (i = 0; i < LIFE_RULES; i++)
 		if (param_rules[i].survival == param.survival &&
-		    param_rules[i].birth == param.birth)
+				param_rules[i].birth == param.birth)
 			return i;
 	return LIFE_RULES;
 }
@@ -242,7 +251,7 @@ copyFromPatternedRule(paramstruct * param, int patterned_rule)
 static void
 printRule(char * string, paramstruct param, Bool verbose)
 {
-	int         i = 1, l;
+	int i = 1, l;
 
 	string[0] = 'S';
 	if (verbose)
@@ -264,8 +273,9 @@ printRule(char * string, paramstruct param, Bool verbose)
 	}
 	string[i] = '\0';
 	if (verbose)
-	  (void) fprintf(stdout, "%s\nbinary rule: Survival 0x%X, Birth 0x%X\n",
-		       string, param.survival, param.birth);
+		(void) fprintf(stdout,
+			"%s\nbinary rule: Survival 0x%X, Birth 0x%X\n",
+			string, param.survival, param.birth);
 }
 
 /*-
@@ -275,8 +285,8 @@ printRule(char * string, paramstruct param, Bool verbose)
 static void
 parseRule(ModeInfo * mi, char * string)
 {
-	int         n, l;
-	char        serving = 0;
+	int n, l;
+	char serving = 0;
 	static Bool found = False;
 
 	if (found)
@@ -331,11 +341,11 @@ parseRule(ModeInfo * mi, char * string)
 static void
 parseFile(ModeInfo *mi)
 {
-	FILE       *file;
+	FILE *file;
 	static Bool done = False;
-	int         firstx, firsty, x = 0, y = 0, z = 0, i = 0;
-	int         c, cprev = ' ', size;
-	char        line[256];
+	int firstx, firsty, x = 0, y = 0, z = 0, i = 0;
+	int c, cprev = ' ', size;
+	char line[256];
 
 	if (done)
 		return;
@@ -348,13 +358,14 @@ parseFile(ModeInfo *mi)
 	}
 	for (;;) {
 		if (!fgets(line, 256, file)) {
-			(void) fprintf(stderr, "could not read header of file \"%s\"\n",
-				       lifefile);
+			(void) fprintf(stderr,
+				"could not read header of file \"%s\"\n",
+				lifefile);
 			(void) fclose(file);
 			return;
 		}
 		if (strncmp(line, "#P", (size_t) 2) == 0 &&
-		    sscanf(line, "#P %d %d %d", &x, &y, &z) == 3)
+				sscanf(line, "#P %d %d %d", &x, &y, &z) == 3)
 			break;
 	}
 	c = getc(file);
@@ -362,9 +373,9 @@ parseFile(ModeInfo *mi)
 		c = getc(file);
 	}
 	if (c == EOF || x <= -127 || y <= -127 || z <= -127 ||
-	    x >= 127 || y >= 127 || z >= 127) {
-		(void) fprintf(stderr, "corrupt file \"%s\" or file to large\n",
-			       lifefile);
+			x >= 127 || y >= 127 || z >= 127) {
+		(void) fprintf(stderr,
+			"corrupt file \"%s\" or file to large\n", lifefile);
 		(void) fclose(file);
 		return;
 	}
@@ -416,7 +427,7 @@ Init3D(life3dstruct * lp)
 static Bool
 AddToList(life3dstruct * lp, unsigned int x, unsigned int y, unsigned int z)
 {
-	CellList   *tmp;
+	CellList *tmp;
 
 	if ((tmp = (CellList *) malloc(sizeof (CellList))) == NULL)
 		return False;
@@ -482,7 +493,7 @@ DelFromEraseList(CellList * cell)
 static void
 MemInit(life3dstruct * lp)
 {
-	int         i;
+	int i;
 
 	for (i = 0; i < BASESIZE; ++i) {
 		if (lp->base[i] != NULL) {
@@ -504,7 +515,7 @@ static Bool
 GetMem(life3dstruct * lp, unsigned int x, unsigned int y, unsigned int z,
 		int *m)
 {
-	int         b, o;
+	int b, o;
 
 	if (lp->memstart) {
 		MemInit(lp);
@@ -515,10 +526,10 @@ GetMem(life3dstruct * lp, unsigned int x, unsigned int y, unsigned int z,
 }
 
 static Bool
-SetMem(life3dstruct * lp,
-       unsigned int x, unsigned int y, unsigned int z, unsigned int val)
+SetMem(life3dstruct * lp, unsigned int x, unsigned int y, unsigned int z,
+		unsigned int val)
 {
-	int         b, o;
+	int b, o;
 
 	if (lp->memstart) {
 		MemInit(lp);
@@ -533,7 +544,7 @@ ChangeMem(life3dstruct * lp,
 		unsigned int x, unsigned int y, unsigned int z,
 		unsigned int val)
 {
-	int         b, o;
+	int b, o;
 
 	if (lp->memstart) {
 		MemInit(lp);
@@ -546,7 +557,7 @@ ChangeMem(life3dstruct * lp,
 static void
 ClearMem(life3dstruct * lp)
 {
-	int         i, j, count;
+	int i, j, count;
 
 	for (i = 0; i < BASESIZE; ++i)
 		if (lp->base[i] != NULL) {
@@ -569,7 +580,7 @@ ClearMem(life3dstruct * lp)
 static Bool
 IncrementNbrs3D(life3dstruct * lp, CellList * cell)
 {
-	int         xc, yc, zc, x, y, z;
+	int xc, yc, zc, x, y, z;
 
 	xc = cell->x;
 	yc = cell->y;
@@ -587,7 +598,7 @@ IncrementNbrs3D(life3dstruct * lp, CellList * cell)
 static void
 End3D(life3dstruct * lp)
 {
-	CellList   *ptr;
+	CellList *ptr;
 
 	while (lp->ptrhead != NULL) {
 		/* Reset3D(lp->ptrhead->x, lp->ptrhead->y, lp->ptrhead->z); */
@@ -605,8 +616,8 @@ static Bool
 RunLife3D(life3dstruct * lp)
 {
 	unsigned int x, y, z, xc, yc, zc;
-	int         c;
-	CellList   *ptr, *ptrnextcell;
+	int c;
+	CellList *ptr, *ptrnextcell;
 	Bool visible = False;
 
 	/* Step 1 - Add 1 to all neighbours of living cells. */
@@ -674,8 +685,8 @@ RunLife3D(life3dstruct * lp)
 static int
 CountCells3D(life3dstruct * lp)
 {
-	CellList   *ptr;
-	int         count = 0;
+	CellList *ptr;
+	int count = 0;
 
 	ptr = lp->ptrhead;
 	while (ptr != NULL) {
@@ -688,8 +699,8 @@ CountCells3D(life3dstruct * lp)
 void
 DisplayList(life3dstruct * lp)
 {
-	CellList   *ptr;
-	int         count = 0;
+	CellList *ptr;
+	int count = 0;
 
 	ptr = lp->ptrhead;
 	while (ptr != NULL) {
@@ -707,7 +718,7 @@ static Bool
 RandomSoup(ModeInfo * mi, int n, int v)
 {
 	life3dstruct *lp = &life3ds[MI_SCREEN(mi)];
-	int         x, y, z;
+	int x, y, z;
 
 	v /= 2;
 	if (v < 1)
@@ -729,8 +740,8 @@ static Bool
 GetPattern(ModeInfo * mi, int pattern_rule, int pattern)
 {
 	life3dstruct *lp = &life3ds[MI_SCREEN(mi)];
-	int         x, y, z, orient, temp;
-	char       *patptr = (char *) NULL;
+	int x, y, z, orient, temp;
+	char *patptr = (char *) NULL;
 #ifdef LIFE_NAMES
 	int pat = 2 * pattern + 1;
 	char * patstrg = (char *) "";
@@ -826,7 +837,7 @@ GetPattern(ModeInfo * mi, int pattern_rule, int pattern)
 static void
 NewViewpoint(life3dstruct * lp, double x, double y, double z)
 {
-	double      k, l, d1, d2;
+	double k, l, d1, d2;
 
 	k = x * x + y * y;
 	l = sqrt(k + z * z);
@@ -882,7 +893,7 @@ static void
 NewPoint(life3dstruct * lp, double x, double y, double z,
 	 register XPoint * cubepts)
 {
-	double      p1, E;
+	double p1, E;
 
 	p1 = x * lp->vx + y * lp->vy;
 	E = lp->B - p1 - z * lp->vz;
@@ -898,11 +909,11 @@ NewPoint(life3dstruct * lp, double x, double y, double z,
 static void
 SortList(life3dstruct * lp)
 {
-	short       dist;
-	double      d, x, y, z, rsize;
-	int         i, r;
-	XPoint      point;
-	CellList   *ptr;
+	short dist;
+	double d, x, y, z, rsize;
+	int i, r;
+	XPoint point;
+	CellList *ptr;
 
 	for (i = 0; i < NBUCKETS; ++i)
 		lp->buckethead[i] = lp->bucketend[i] = (CellList *) NULL;
@@ -972,10 +983,10 @@ static void
 DrawFace(ModeInfo * mi, int color, XPoint * cubepts,
 		int p1, int p2, int p3, int p4)
 {
-	Display    *display = MI_DISPLAY(mi);
-	GC          gc = MI_GC(mi);
+	Display *display = MI_DISPLAY(mi);
+	GC gc = MI_GC(mi);
 	life3dstruct *lp = &life3ds[MI_SCREEN(mi)];
-	XPoint      facepts[5];
+	XPoint facepts[5];
 
 	facepts[0] = cubepts[p1];
 	facepts[1] = cubepts[p2];
@@ -983,17 +994,31 @@ DrawFace(ModeInfo * mi, int color, XPoint * cubepts,
 	facepts[3] = cubepts[p4];
 	facepts[4] = cubepts[p1];
 
-	XSetForeground(display, gc, lp->colors[color]);
+	if (color != BLACK && MI_NPIXELS(mi) <= 2)
+		XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
+	else
+		XSetForeground(display, gc, lp->colors[color]);
 	if (!lp->wireframe) {
-		XFillPolygon(display, lp->dbuf, gc, facepts, 4,
+		if (color != BLACK && MI_NPIXELS(mi) <= 2) {
+			XGCValues gcv;
+
+			gcv.stipple = lp->pixmaps[lp->colors[color]];
+			gcv.foreground = MI_WHITE_PIXEL(mi);
+			gcv.background = MI_BLACK_PIXEL(mi);
+			XChangeGC(display, lp->stippledGC,
+				GCStipple | GCForeground | GCBackground, &gcv);
+			gc = lp->stippledGC;
+		}
+		XFillPolygon(display, (Drawable) lp->dbuf, gc, facepts, 4,
 			Convex, CoordModeOrigin);
+		gc = MI_GC(mi);
 		if (color == BLACK || MI_NPIXELS(mi) <= 2) {
 			XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 		} else {
 			XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
 		}
 	}
-	XDrawLines(display, lp->dbuf, gc, facepts, 5, CoordModeOrigin);
+	XDrawLines(display, (Drawable) lp->dbuf, gc, facepts, 5, CoordModeOrigin);
 }
 
 #define LEN 0.45
@@ -1003,11 +1028,11 @@ static int
 DrawCube(ModeInfo * mi, CellList * cell)
 {
 	life3dstruct *lp = &life3ds[MI_SCREEN(mi)];
-	XPoint      cubepts[8];	/* screen coords for point */
-	int         i = 0, out;
+	XPoint cubepts[8];	/* screen coords for point */
+	int i = 0, out;
 	unsigned int mask;
-	double      x, y, z;
-	double      dx, dy, dz;
+	double x, y, z;
+	double dx, dy, dz;
 
 	x = (double) cell->x - lp->ox;
 	y = (double) cell->y - lp->oy;
@@ -1069,16 +1094,16 @@ static void
 DrawScreen(ModeInfo * mi)
 {
 	life3dstruct *lp = &life3ds[MI_SCREEN(mi)];
-	Display    *display = MI_DISPLAY(mi);
-	GC          gc = MI_GC(mi);
-	CellList   *ptr;
-	CellList   *eraserptr;
-	int         i;
+	Display *display = MI_DISPLAY(mi);
+	GC gc = MI_GC(mi);
+	CellList *ptr;
+	CellList *eraserptr;
+	int i;
 
 	SortList(lp);
 
 	XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
-	XFillRectangle(display, lp->dbuf, gc, 0, 0,
+	XFillRectangle(display, (Drawable) lp->dbuf, gc, 0, 0,
 		lp->width, lp->height);
 
 	/* Erase dead cubes */
@@ -1105,24 +1130,24 @@ DrawScreen(ModeInfo * mi)
 		if (size >= 10 * FONT_WIDTH) {
 			/* hard code these to corners */
 			XSetForeground(display, gc, MI_WHITE_PIXEL(mi));
-			XDrawString(display, lp->dbuf, gc,
+			XDrawString(display, (Drawable) lp->dbuf, gc,
 				16 + lp->labelOffsetX,
 				16 + lp->labelOffsetY + FONT_HEIGHT,
 				lp->ruleString, strlen(lp->ruleString));
-			XDrawString(display, lp->dbuf, gc,
+			XDrawString(display, (Drawable) lp->dbuf, gc,
 				16 + lp->labelOffsetX,
 				MI_HEIGHT(mi) - 16 -
-			       	lp->labelOffsetY - FONT_HEIGHT / 2,
+				lp->labelOffsetY - FONT_HEIGHT / 2,
 				lp->nameString, strlen(lp->nameString));
 		}
 	}
 	XFlush(display);
-	XCopyArea(display, lp->dbuf, MI_WINDOW(mi), gc,
+	XCopyArea(display, (Drawable) lp->dbuf, MI_WINDOW(mi), gc,
 		0, 0, lp->width, lp->height, 0, 0);
 
 #if 0
 	{
-		int         count = 0, v = 0;
+		int count = 0, v = 0;
 
 
 		(void) printf("Pop=%-4d  Viewpoint (%3d,%3d,%3d)  Origin (%3d,%3d,%3d)  Mode %dx%d\
@@ -1137,8 +1162,7 @@ DrawScreen(ModeInfo * mi)
 static Bool
 shooter(life3dstruct * lp)
 {
-	int         hsp, vsp, asp, hoff = 1, voff = 1, aoff = 1, r, c2,
-	            r2, s2;
+	int hsp, vsp, asp, hoff = 1, voff = 1, aoff = 1, r, c2, r2, s2;
 
 	/* Generate the glider at the edge of the screen */
 #define V 10
@@ -1337,18 +1361,29 @@ shooter(life3dstruct * lp)
 static void
 free_life3d(Display *display, life3dstruct *lp)
 {
+	int shade;
+
 	if (lp->eraserhead.next != NULL)
 		End3D(lp);
-        if (lp->dbuf != None) {
+	if (lp->dbuf != None) {
 		XFreePixmap(display, lp->dbuf);
 		lp->dbuf = None;
 	}
+	if (lp->stippledGC != None) {
+		XFreeGC(display, lp->stippledGC);
+		lp->stippledGC = None;
+	}
+	for (shade = 0; shade < lp->init_bits; shade++) {
+		XFreePixmap(display, lp->pixmaps[shade]);
+	}
+	lp->init_bits = 0;
 }
 
 void
 init_life3d(ModeInfo * mi)
 {
 	Display *display = MI_DISPLAY(mi);
+	Window window = MI_WINDOW(mi);
 	life3dstruct *lp;
 	int i, npats;
 
@@ -1359,8 +1394,23 @@ init_life3d(ModeInfo * mi)
 	}
 	lp = &life3ds[MI_SCREEN(mi)];
 
+	if (MI_NPIXELS(mi) <= 2) {
+		if (lp->stippledGC == None) {
+			XGCValues   gcv;
+			gcv.fill_style = FillOpaqueStippled;
+			if ((lp->stippledGC = XCreateGC(display, window,
+					GCFillStyle, &gcv)) == None) {
+				free_life3d(display, lp);
+				return;
+			}
+		}
+		if (lp->init_bits == 0) {
+			for (i = 1; i < NUMSTIPPLES; i++) {
+				LIFE3DBITS(stipples[i], STIPPLESIZE, STIPPLESIZE);
+			}
+		}
+	}
 	lp->generation = 0;
-
 	lp->labelOffsetX = NRAND(8);
 	lp->labelOffsetY = NRAND(8);
 	parseRule(mi, lp->ruleString);
@@ -1379,8 +1429,8 @@ init_life3d(ModeInfo * mi)
 	}
 	if (!lp->eraserhead.next) {
 		lp->metaDist = (double) NRAND(360);
-                lp->metaAlt = (double) NRAND(360);
-                lp->metaAzm = (double) NRAND(360);
+		lp->metaAlt = (double) NRAND(360);
+		lp->metaAzm = (double) NRAND(360);
 		lp->ncolumns = MAXCOLUMNS;
 		lp->nrows = MAXROWS;
 		lp->nstacks = MAXSTACKS;
@@ -1405,8 +1455,18 @@ init_life3d(ModeInfo * mi)
 			NRAND(MI_NPIXELS(mi) / COLORBASE) +
 			2 * MI_NPIXELS(mi) / COLORBASE);
 	} else {
-		lp->colors[1] = lp->colors[2] = lp->colors[3] =
-			MI_WHITE_PIXEL(mi);
+		/*lp->colors[1] = lp->colors[2] = lp->colors[3] =
+			MI_WHITE_PIXEL(mi);*/
+		i = NRAND(3);
+
+		lp->colors[1] = NRAND(NUMSTIPPLES - 1);
+		lp->colors[2] = NRAND(NUMSTIPPLES - 1);
+		while (lp->colors[2] == lp->colors[1])
+			lp->colors[2] = NRAND(NUMSTIPPLES - 1);
+		lp->colors[3] = NRAND(NUMSTIPPLES - 1);
+		while (lp->colors[3] == lp->colors[1] ||
+			lp->colors[3] == lp->colors[2])
+			lp->colors[3] = NRAND(NUMSTIPPLES - 1);
 	}
 	lp->colors[4] = MI_WHITE_PIXEL(mi);
 	lp->width = MI_WIDTH(mi);
@@ -1450,7 +1510,7 @@ init_life3d(ModeInfo * mi)
 		XFreePixmap(display, lp->dbuf);
 		lp->dbuf = None;
 	}
-	if ((lp->dbuf = XCreatePixmap(display, MI_WINDOW(mi),
+	if ((lp->dbuf = XCreatePixmap(display, window,
 		lp->width, lp->height, MI_DEPTH(mi))) == None) {
 		free_life3d(display, lp);
 		return;
@@ -1506,7 +1566,7 @@ void
 release_life3d(ModeInfo * mi)
 {
 	if (life3ds != NULL) {
-		int         screen;
+		int screen;
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_life3d(MI_DISPLAY(mi), &life3ds[screen]);
@@ -1532,7 +1592,7 @@ refresh_life3d(ModeInfo * mi)
 void
 change_life3d(ModeInfo * mi)
 {
-	int         npats;
+	int npats;
 	life3dstruct *lp;
 
 	if (life3ds == NULL)
