@@ -218,11 +218,11 @@ text_font_width(char *string)
 				 * a monospaced font. */
 				if (t) {
 					t--;
-					x -= char_width[' '];
+					x -= char_width[(int) (' ')];
 				}
 				break;
 			case '\t':
-				x += char_width[' '] * (8 - (t % 8));
+				x += char_width[(int) (' ')] * (8 - (t % 8));
 				t = ((t + 8) / 8) * 8;
 				break;
 			case '\r':
@@ -266,7 +266,7 @@ add_blanks(marqueestruct * mp)
 		mp->modwords[mp->t] = '\0';
 		(void) strcat(mp->modwords, "  ");
 	}
-	mp->x -= 2 * char_width[' '];
+	mp->x -= 2 * char_width[(int) (' ')];
 	if (mp->x <= -char_width[(int) (unsigned char) mp->modwords[0]]) {
 		mp->x += char_width[(int) (unsigned char) mp->modwords[0]];
 		(void) memcpy(mp->modwords, &(mp->modwords[1]), mp->nonblanks);
@@ -324,7 +324,6 @@ init_marquee(ModeInfo * mi)
 		mode_font = getFont(display);
 	if (mp->gc == NULL && mode_font != None) {
 		gcv.font = mode_font->fid;
-		XSetFont(display, MI_GC(mi), mode_font->fid);
 		gcv.graphics_exposures = False;
 		gcv.foreground = MI_WHITE_PIXEL(mi);
 		gcv.background = MI_BLACK_PIXEL(mi);
@@ -428,7 +427,7 @@ draw_marquee(ModeInfo * mi)
 				if (mp->t) {
 					/* see note in text_font_width */
 					mp->t--;
-					mp->x -= char_width[' '];
+					mp->x -= char_width[(int) (' ')];
 				}
 				break;
 			case '\v':
@@ -449,7 +448,7 @@ draw_marquee(ModeInfo * mi)
 			case '\t':
 				(void) XDrawString(display, window, mp->gc, mp->x, mp->y + mp->ascent,
 						   space, 8 - (mp->t % 8));
-				mp->x += char_width[' '] * (8 - (mp->t % 8));
+				mp->x += char_width[(int) (' ')] * (8 - (mp->t % 8));
 				mp->t = ((mp->t + 8) / 8) * 8;
 				break;
 			case '\r':
