@@ -109,10 +109,40 @@ ModStruct   nose_description =
 #define TALK 1
 #define FREEZE 2
 
-#ifndef USE_MB
-extern XFontStruct *getFont(Display * display);
-#else
+#ifdef USE_MB
+static XFontSet mode_font = None;
+static int getFontHeight(XFontSet f)
+{
+	XRectangle ink, log;
+
+	if (f == None) {
+		return 8;
+	} else {
+		/*XmbTextExtents(mode_font, "My", strlen("My"), &ink, &log); */
+		XmbTextExtents(mode_font, "M", strlen("M"), &ink, &log);
+		return log.height;
+	}
+}
+static int getTextWidth(char *string)
+{
+	XRectangle ink, logical;
+
+	XmbTextExtents(mode_font, string, strlen(string), &ink, &logical);
+	return logical.width;
+}
 extern XFontSet getFontSet(Display * display);
+#define DrawString(d, p, gc, start, ascent, string, len) (void) XmbDrawString(\
+	d, p, mode_font, gc, start, ascent, string, len)
+#else
+static XFontStruct *mode_font = None;
+#define getFontHeight(f) ((f == None) ? 8 : f->ascent + f->descent)
+static int getTextWidth(char *string)
+{
+	return XTextWidth(mode_font, string, strlen(string));
+}      
+extern XFontStruct *getFont(Display * display);
+#define DrawString(d, p, gc, start, ascent, string, len) (void) XDrawString(\
+	d, p, gc, start, ascent, string, len)
 #endif
 extern char *getWords(int screen, int screens);
 extern int  isRibbon(void);
@@ -140,26 +170,6 @@ typedef struct {
 
 static nosestruct *noses = (nosestruct *) NULL;
 
-#ifdef USE_MB
-static XFontSet mode_font = None;
-#else
-static XFontStruct *mode_font = None;
-#endif
-
-#ifdef USE_MB
-static int font_height(XFontSet f) {
-  XRectangle ink, log;
-  if (f == None) {
-	return 8;
-  } else {
-	XmbTextExtents(mode_font, "M", strlen("M"), &ink, &log);
-	return log.height;
-  }
-}
-#else
-#define font_height(f) ((f == None) ? 8 : f->ascent + f->descent)
-#endif
-
 #define LEFT 001
 #define RIGHT 002
 #define DOWN 004
@@ -180,11 +190,11 @@ free_nose(Display *display, nosestruct *np)
 
 	if (np->text_fg_gc != None) {
 		XFreeGC(display, np->text_fg_gc);
-	    np->text_fg_gc = None;
+		np->text_fg_gc = None;
 	}
 	if (np->text_bg_gc != None) {
 		XFreeGC(display, np->text_bg_gc);
-	    np->text_bg_gc = None;
+		np->text_bg_gc = None;
 	}
 	for (pix = 0; pix < PIXMAPS; pix++) {
 		if (np->position[pix] != None) {
@@ -234,7 +244,8 @@ pickClothes(ModeInfo * mi)
 	/* DOWN NOSE GUY */
 	if ((shoe_pix = XCreateBitmapFromData(display, window,
 			(char *) nose_shoe_front_bits,
-			nose_shoe_front_width, nose_shoe_front_height)) == None){
+			nose_shoe_front_width,
+			nose_shoe_front_height)) == None) {
 		return False;
 	}
 	COPY(display, gc, shoe_color, shoe_pix, np->position[D],
@@ -243,7 +254,8 @@ pickClothes(ModeInfo * mi)
 	     nose_shoe_front_width, nose_shoe_front_height);
 	if ((face_pix = XCreateBitmapFromData(display, window,
 			(char *) nose_face_down_bits,
-			nose_face_down_width, nose_face_down_height)) == None) {
+			nose_face_down_width,
+			nose_face_down_height)) == None) {
 		XFreePixmap(display, shoe_pix);
 		return False;
 	}
@@ -291,7 +303,8 @@ pickClothes(ModeInfo * mi)
 	}
 	if ((face_pix = XCreateBitmapFromData(display, window,
 			(char *) nose_face_front_bits,
-			nose_face_front_width, nose_face_front_height)) == None) {
+			nose_face_front_width,
+			nose_face_front_height)) == None) {
 		XFreePixmap(display, hat_pix);
 		return False;
 	}
@@ -301,7 +314,8 @@ pickClothes(ModeInfo * mi)
 	/* FRONT LEFT NOSE GUY */
 	if ((shoel_pix = XCreateBitmapFromData(display, window,
 			(char *) nose_shoe_left_bits,
-			nose_shoe_left_width, nose_shoe_left_height)) == None) {
+			nose_shoe_left_width,
+			nose_shoe_left_height)) == None) {
 		XFreePixmap(display, hat_pix);
 		XFreePixmap(display, face_pix);
 		return False;
@@ -326,7 +340,8 @@ pickClothes(ModeInfo * mi)
 	/* FRONT RIGHT NOSE GUY */
 	if ((shoer_pix = XCreateBitmapFromData(display, window,
 			(char *) nose_shoe_right_bits,
-			nose_shoe_right_width, nose_shoe_right_height)) == None) {
+			nose_shoe_right_width,
+			nose_shoe_right_height)) == None) {
 		XFreePixmap(display, hat_pix);
 		XFreePixmap(display, shoel_pix);
 		XFreePixmap(display, face_pix);
@@ -368,7 +383,8 @@ pickClothes(ModeInfo * mi)
 	}
 	if ((face_pix = XCreateBitmapFromData(display, window,
 			(char *) nose_face_left_bits,
-			nose_face_left_width, nose_face_left_height)) == None) {
+			nose_face_left_width,
+			nose_face_left_height)) == None) {
 		XFreePixmap(display, hat_pix);
 		XFreePixmap(display, shoer_pix);
 		return False;
@@ -379,7 +395,8 @@ pickClothes(ModeInfo * mi)
 	/* LEFT NOSE GUY STEPPING */
 	if ((shoel_pix = XCreateBitmapFromData(display, window,
 			(char *) nose_step_left_bits,
-			nose_step_left_width, nose_step_left_height)) == None) {
+			nose_step_left_width,
+			nose_step_left_height)) == None) {
 		XFreePixmap(display, hat_pix);
 		XFreePixmap(display, face_pix);
 		XFreePixmap(display, shoer_pix);
@@ -407,7 +424,8 @@ pickClothes(ModeInfo * mi)
 	/* RIGHT NOSE GUY */
 	if ((face_pix = XCreateBitmapFromData(display, window,
 			(char *) nose_face_right_bits,
-			nose_face_right_width, nose_face_right_height)) == None) {
+			nose_face_right_width,
+			nose_face_right_height)) == None) {
 		XFreePixmap(display, hat_pix);
 		XFreePixmap(display, shoer_pix);
 		return False;
@@ -433,7 +451,8 @@ pickClothes(ModeInfo * mi)
 	/* RIGHT NOSE GUY STEPPING */
 	if ((shoer_pix = XCreateBitmapFromData(display, window,
 			(char *) nose_step_right_bits,
-			nose_step_right_width, nose_step_right_height)) == None) {
+			nose_step_right_width,
+			nose_step_right_height)) == None) {
 		XFreePixmap(display, face_pix);
 		XFreePixmap(display, hat_pix);
 		return False;
@@ -557,19 +576,17 @@ talk(ModeInfo * mi, Bool force_erase)
 	Display    *display = MI_DISPLAY(mi);
 	Window      window = MI_WINDOW(mi);
 	nosestruct *np = &noses[MI_SCREEN(mi)];
-	int         width = 0, height, Y, Z, total = 0;
+	int         width = 0, height = 0, Y, Z, total = 0;
 	register char *p, *p2;
 	char        buf[BUFSIZ], args[MAXLINES][MAXWIDTH];
-#ifdef USE_MB
-	XRectangle ink, log;
-#endif
 
 	/* clear what we've written */
 	if (np->talking || force_erase) {
 		if (!np->talking)
 			return;
-		XFillRectangle(display, window, np->text_bg_gc, np->s.x - 5, np->s.y - 5,
-			       np->s.width + 10, np->s.height + 10);
+		XFillRectangle(display, window, np->text_bg_gc,
+			np->s.x - 5, np->s.y - 5,
+			np->s.width + 10, np->s.height + 10);
 		np->talking = False;
 		if (!force_erase)
 			np->state = MOVE;
@@ -578,51 +595,46 @@ talk(ModeInfo * mi, Bool force_erase)
 	np->talking = True;
 	walk(mi, FRONT);
 	p = strncpy(buf, np->words, BUFSIZ);
-	if (!(p2 = (char *) strchr(p, '\n')) || !p2[1]) {
-		(void) strncpy(args[0], np->words, MAXWIDTH - 1);
-		total = strlen(args[0]);
-		args[0][MAXWIDTH - 1] = '\0';
-		if (mode_font == None)
-			width = 8;
-		else {
-#ifdef USE_MB
-			XmbTextExtents(mode_font, np->words, total, &ink, &log);
-			width = ink.width;
-#else
-			width = XTextWidth(mode_font, np->words, total);
-#endif
-		}
-		height = 0;
-	} else
-		/* p2 now points to the first '\n' */
-		for (height = 0; p && height < MAXLINES; height++) {
-			int         w;
-
+	while (strlen(p) > 0) {
+		p2 = p + strlen(p) - 1;
+		if (*p2 == '\n')
 			*p2 = 0;
-#ifdef USE_MB
-			XmbTextExtents(mode_font, p, p2 - p, &ink, &log);
-			if (mode_font != None && (w = log.width) > width)
-			  width = w;
-#else
-			if (mode_font != None &&
-					(w = XTextWidth(mode_font, p, p2 - p)) > width)
-				width = w;
-#endif
-			total += p2 - p;	/* total chars; count to determine reading time */
-			(void) strncpy(args[height], p, MAXWIDTH - 1);
-			args[height][MAXWIDTH - 1] = '\0';
-			p = p2 + 1;
-			if (!(p2 = (char *) strchr(p, '\n')))
-				break;
-		}
+		else
+			break;
+	}
+	for (height = 0; p && height < MAXLINES; height++) {
+		int w;
+		char *p3;
 
-	height++;
+		if (!(p2 = (char *) strchr(p, '\n')) || !p2[1]) {
+			p2 = p + strlen(p);
+		
+		}
+		/* p2 now points to the first '\n' */
+		*p2 = 0;
+		for (w = 0; w < p2 - p; w++) {
+			p3 = p + w;
+			if (*p3 == '\t') /* this should be improved */
+				*p3 = ' ';
+		}
+		(void) strncpy(args[height], p, MAXWIDTH - 1);
+		args[height][MAXWIDTH - 1] = '\0';
+		if (mode_font == None && height == 0)
+			width = 8;
+		if (mode_font != None && (w =
+				getTextWidth(args[height])) > width)
+			width = w;
+		total += p2 - p;  /* total chars; count to determine reading time */
+		if (p == p2)
+			break;
+		p = p2 + 1;
+	}
 	/*
 	 * Figure out the height and width in imagepixels (height, width) extend the
 	 * new box by 15 pixels on the sides (30 total) top and bottom.
 	 */
 	np->s.width = width + 30;
-	np->s.height = height * font_height(mode_font) + 30;
+	np->s.height = height * getFontHeight(mode_font) + 30;
 	if (np->x - np->s.width - 10 < 5)
 		np->s.x = 5;
 	else if ((np->s.x = np->x + 32 - (np->s.width + 15) / 2)
@@ -644,18 +656,13 @@ talk(ModeInfo * mi, Bool force_erase)
 	XDrawRectangle(display, window, np->text_fg_gc,
 	      np->s.x + 7, np->s.y + 7, np->s.width - 15, np->s.height - 15);
 
-	Y = 15 + font_height(mode_font);
+	Y = 15 + getFontHeight(mode_font);
 
 	/* now print each string in reverse order (start at bottom of box) */
 	for (Z = 0; Z < height; Z++) {
-#ifdef USE_MB
-		(void) XmbDrawString(display, window, mode_font, np->text_fg_gc,
-			 np->s.x + 15, np->s.y + Y, args[Z], strlen(args[Z]));
-#else
-		(void) XDrawString(display, window, np->text_fg_gc,
+		DrawString(display, window, np->text_fg_gc,
 			np->s.x + 15, np->s.y + Y, args[Z], strlen(args[Z]));
-#endif
-		Y += font_height(mode_font);
+		Y += getFontHeight(mode_font);
 	}
 	np->busyLoop = (total / 15) * 10;
 	if (np->busyLoop < 30)
@@ -811,17 +818,15 @@ init_nose(ModeInfo * mi)
 	if (np->text_fg_gc == None && mode_font != None) {
 #ifndef USE_MB
 		gcv.font = mode_font->fid;
-		XSetFont(display, gc, mode_font->fid);
 #endif
 		gcv.graphics_exposures = False;
 		gcv.foreground = MI_WHITE_PIXEL(mi);
 		gcv.background = MI_BLACK_PIXEL(mi);
 		if ((np->text_fg_gc = XCreateGC(display, window,
-#ifdef USE_MB
-				 GCForeground | GCBackground | GCGraphicsExposures,
-#else
-				 GCForeground | GCBackground | GCGraphicsExposures | GCFont,
+#ifndef USE_MB
+				 GCFont |
 #endif
+				 GCForeground | GCBackground | GCGraphicsExposures,
 				 &gcv)) == None) {
 			free_nose(display, np);
 			return;
@@ -829,11 +834,10 @@ init_nose(ModeInfo * mi)
 		gcv.foreground = MI_BLACK_PIXEL(mi);
 		gcv.background = MI_WHITE_PIXEL(mi);
 		if ((np->text_bg_gc = XCreateGC(display, window,
-#ifdef USE_MB
-				 GCForeground | GCBackground | GCGraphicsExposures,
-#else
-				 GCForeground | GCBackground | GCGraphicsExposures | GCFont,
+#ifndef USE_MB
+				 GCFont |
 #endif
+				 GCForeground | GCBackground | GCGraphicsExposures,
 				 &gcv)) == None) {
 			free_nose(display, np);
 			return;
