@@ -321,8 +321,6 @@ static int setup_random_colormap (ModeInfo * mi)
     if (ncolors < 1) {
 	sp->mono = True;
     }
-    ncolors++;
-    sp->count = ncolors;
 
     if (sp->mono) {
 	if (colors != NULL) {
@@ -350,6 +348,8 @@ static int setup_random_colormap (ModeInfo * mi)
 	}
 	return True;
     }
+    ncolors++;
+    sp->count = ncolors;
     (void) memcpy (colors + sp->count, colors, sp->count * sizeof(*colors));
     colors[sp->count].pixel = MI_WHITE_PIXEL(mi);
 
@@ -734,7 +734,8 @@ static int setup_display (ModeInfo * mi)
     }
     else
     {
-	if (!setup_random_colormap (mi))
+	if (!setup_random_colormap (mi)) /* PseudoColor can error out */
+	/*if (!setup_original_colormap (mi))*/
 		return False;
     }
     return True;
