@@ -141,7 +141,7 @@ static void
 free_puzzle(Display * display, puzzlestruct * pp)
 {
 	if (pp->fixbuff != NULL) {
-		(void) free((void *) pp->fixbuff);
+		free(pp->fixbuff);
 		pp->fixbuff = (int *) NULL;
 	}
 	if (pp->bufferBox != None) {
@@ -185,7 +185,6 @@ NumberScreen(ModeInfo * mi)
 
 		pp->done = 1;
 		gcv.font = mode_font->fid;
-		XSetFont(display, MI_GC(mi), mode_font->fid);
 		gcv.graphics_exposures = False;
 		gcv.foreground = MI_WHITE_PIXEL(mi);
 		gcv.background = MI_BLACK_PIXEL(mi);
@@ -496,7 +495,7 @@ init_puzzle(ModeInfo * mi)
 	pp->excount = MI_COUNT(mi);
 	if (pp->excount < 0) {
 		if (pp->fixbuff != NULL) {
-			(void) free((void *) pp->fixbuff);
+			free(pp->fixbuff);
 			pp->fixbuff = (int *) NULL;
 		}
 		pp->excount = NRAND(-pp->excount) + 1;
@@ -656,7 +655,7 @@ release_puzzle(ModeInfo * mi)
 
 		for (screen = 0; screen < MI_NUM_SCREENS(mi); screen++)
 			free_puzzle(MI_DISPLAY(mi), &puzzles[screen]);
-		(void) free((void *) puzzles);
+		free(puzzles);
 		puzzles = (puzzlestruct *) NULL;
 	}
 #ifdef NUMBERED
