@@ -329,13 +329,15 @@ void CardView::draw()
 #endif
 		XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 		XDrawLine(display, window, gc,
-			x() + 1, y() + 1, x() + width() - 3, y() + 1);
+			x() + 1, y() + 1, x() + width() - 2, y() + 1);
 		XDrawLine(display, window, gc,
-			x() + 1, y() + height() - 2, x() + width() - 3, y() + height() - 2);
+			x() + 1, y() + height() - 2,
+			x() + width() - 2, y() + height() - 2);
 		XDrawLine(display, window, gc,
-			x() + 1, y() + 1, x() + 1, y() + height() - 3);
+			x() + 1, y() + 1, x() + 1, y() + height() - 2);
 		XDrawLine(display, window, gc,
-			x() + width() - 2, y() + 1, x() + width() - 2, y() + height() - 3);
+			x() + width() - 2, y() + 1,
+			x() + width() - 2, y() + height() - 2);
 	} else {
 		int n;
 
@@ -344,17 +346,21 @@ void CardView::draw()
 			x(), y(), width(), height());
 		XSetForeground(display, gc, MI_BLACK_PIXEL(mi));
 		n = x() + int_round(int_round(width() * 0.3));
-		XDrawLine(display, window, gc, n, y() + int_round(height() * 0.1),
-			n, y() + int_round(height() * 0.9));
-		n = x() + int_round(width() * 0.7);
-		XDrawLine(display, window, gc, n, y() + int_round(height() * 0.1),
-			n, y() + int_round(height() * 0.9));
+		XDrawLine(display, window, gc,
+			n, y() + int_round(height() * 0.1),
+			n, y() + int_round(height() * 0.9) - 1);
+		n = x() + int_round(width() * 0.7) - 1;
+		XDrawLine(display, window, gc,
+			n, y() + int_round(height() * 0.1),
+			n, y() + int_round(height() * 0.9) - 1);
 		n = y() + int_round(height() * 0.3);
-		XDrawLine(display, window, gc, x() + int_round(height() * 0.1), n,
-			x() + int_round(width() * 0.9), n);
-		n = y() + int_round(height() * 0.7);
-		XDrawLine(display, window, gc, x() + int_round(width() * 0.1), n,
-			x() + int(width() * 0.9), n);
+		XDrawLine(display, window, gc,
+			x() + int_round(height() * 0.1), n,
+			x() + int_round(width() * 0.9) - 1, n);
+		n = y() + int_round(height() * 0.7) - 1;
+		XDrawLine(display, window, gc,
+			x() + int_round(width() * 0.1), n,
+			x() + int(width() * 0.9) - 1, n);
 	}
 	// Shadow
 #if 1
@@ -1242,7 +1248,7 @@ static XrmOptionDescRec opts[] =
 
 static argtype vars[] =
 {
-	{(caddr_t *) & trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool}
+	{(void *) & trackmouse, (char *) "trackmouse", (char *) "TrackMouse", (char *) DEF_TRACKMOUSE, t_Bool}
 };
 
 static OptionStruct desc[] =
@@ -1302,7 +1308,7 @@ init_solitare(ModeInfo * mi)
 		mode_font = getFont(display);
 	  if (mode_font != None) {
 			gcv.font = mode_font->fid;
-			XSetFont(display, MI_GC(mi), mode_font->fid);
+			/*XSetFont(display, MI_GC(mi), mode_font->fid);*/
 			gcv.graphics_exposures = False;
 			gcv.foreground = MI_WHITE_PIXEL(mi);
 			gcv.background = MI_BLACK_PIXEL(mi);
