@@ -491,8 +491,8 @@ init_toneclock(ModeInfo * mi)
 		} else {
 			XFillRectangle(display, (Drawable) tclock->dbuf, tclock->dbuf_gc,
 				0, 0, tclock->win_width, tclock->win_height);
-			XSetBackground(display, MI_GC(mi), MI_BLACK_PIXEL(mi));
-			XSetFunction(display, MI_GC(mi), GXcopy);
+			/*XSetBackground(display, MI_GC(mi), MI_BLACK_PIXEL(mi));
+			XSetFunction(display, MI_GC(mi), GXcopy);*/
 		}
 	}
 #endif
@@ -651,10 +651,10 @@ init_toneclock(ModeInfo * mi)
 	       }
 	     if ( tclock->moving )
 	       {
-		  tclock->a_x = floor( ( tclock->win_width / 2 ) - 1.05 *
+		  tclock->a_x = (int) floor( ( tclock->win_width / 2 ) - 1.05 *
 					( tclock->radius + tclock->max_radius )
 					);
-		  tclock->a_y = floor( ( tclock->win_height / 2 ) - 1.05 *
+		  tclock->a_y = (int) floor( ( tclock->win_height / 2 ) - 1.05 *
 					( tclock->radius + tclock->max_radius )
 					);
 		  tclock->vx = (NRAND(15) - 7) * PI_RAD;
