@@ -40,6 +40,10 @@ static const char sccsid[] = "@(#)xcl.c    5.00 2000/11/01 xlockmore";
 #include "xlock.h"        /* in xlockmore distribution */
 #endif
 
+#ifdef WIN32
+#include <sys/time.h>
+#endif
+
 #include "xcl.h"             /* model line data file */
 
 #ifdef MODE_xcl
@@ -365,7 +369,7 @@ void init_xcl(ModeInfo * mi)
 
     dp->bg = MI_BLACK_PIXEL(mi);
 
-    if(MI_IS_MONO(mi))
+    if(MI_NPIXELS(mi) <= 2)
       for(i=0;i< dp->planes; i++) {
         dp->planecolor[i] = MI_WHITE_PIXEL(mi);
       }
