@@ -498,13 +498,19 @@ getImage(ModeInfo * mi, XImage ** logo,
 	     {
 		if ( MI_NPIXELS( mi ) > 2 )
 		  {
+		     Colormap magick_colormap;
+		     if (*ncm == None) {
+			magick_colormap = MI_COLORMAP(mi);
+		     } else {
+			magick_colormap = *ncm;
+		     }
 		     if ( MagickSuccess == MagickFileToImage( mi ,
 							     bitmap_local ,
-							     logo) )
+							     logo ,
+							      magick_colormap 
+							      ) )
 		       {
 			  *graphics_format = IS_MAGICKFILE;
-			  if ( !fixedColors( mi ) )
-			    SetImageColors( display , *ncm );
 			  *black = GetColor(mi, MI_BLACK_PIXEL(mi));
 			  (void) GetColor(mi, MI_WHITE_PIXEL(mi));
 			  (void) GetColor(mi, MI_BG_PIXEL(mi));
@@ -521,10 +527,16 @@ getImage(ModeInfo * mi, XImage ** logo,
 # ifndef STANDALONE
 		if (readable(bitmap_local)) {
 			if (MI_NPIXELS(mi) > 2) {
-				if (RasterSuccess == RasterFileToImage(mi, bitmap_local, logo)) {
+			   Colormap ras_colormap;
+			   if (*ncm == None) {
+			      ras_colormap = MI_COLORMAP(mi);
+			   } else {
+			      ras_colormap = *ncm;
+			   }
+				if (RasterSuccess == RasterFileToImage(mi,
+					       bitmap_local, logo ,
+					       ras_colormap )) {
 					*graphics_format = IS_RASTERFILE;
-					if (!fixedColors(mi))
-						SetImageColors(display, *ncm);
 					*black = GetColor(mi, MI_BLACK_PIXEL(mi));
 					(void) GetColor(mi, MI_WHITE_PIXEL(mi));
 					(void) GetColor(mi, MI_BG_PIXEL(mi));
@@ -811,46 +823,54 @@ getWords(int screen, int screens)
 						      (char *) DEF_PROGRAM : program);
 					(void) strcat(progerr, ": not found\n");
 					if (!strcmp(&buf[screen * BUFSIZ], progerr))
-						switch (NRAND(12)) {
+						switch (NRAND(14)) {
 							case 0:
 								(void) strcat(&buf[screen * BUFSIZ],
-									      "( Get with the program, bub. )\n");
+									      "(Get with the program, bub.)\n");
 								break;
 							case 1:
 								(void) strcat(&buf[screen * BUFSIZ],
-									      "( I blow my nose at you, you silly person! )\n");
+									      "(I blow my nose at you, you silly person!)");
 								break;
 							case 2:
 								(void) strcat(&buf[screen * BUFSIZ],
-									      "\nThe resource you want to\nset is `program'.\n");
+									      "(The resource you want to\nset is `program'.)");
 								break;
 							case 3:
 								(void) strcat(&buf[screen * BUFSIZ],
-									      "\nHelp!!  Help!!\nAAAAAAGGGGHHH!!  \n\n");
+									      "(Help!!  Help!!\nAAAAAAGGGGHHH!!)");
 								break;
 							case 4:
 								(void) strcat(&buf[screen * BUFSIZ],
-									      "( Hey, who called me `Big Nose'? )\n");
+									      "(Hey, who called me `Big Nose'?)");
 								break;
 							case 5:
 								(void) strcat(&buf[screen * BUFSIZ],
-									      "( Hello?  Are you paying attention? )\n");
+									      "(Hello?  Are you paying attention?)");
 								break;
 							case 6:
 								(void) strcat(&buf[screen * BUFSIZ],
-									      "sh: what kind of fool do you take me for? \n");
+									      "(sh: what kind of fool do you take me for?)");
 								break;
 							case 7:
 								(void) strcat(&buf[screen * BUFSIZ],
-									      "\nRun me with -program \"fortune -o\".\n");
+									      "(Run me with -program \"fortune -o\".)");
 								break;
 							case 8:
 								(void) strcat(&buf[screen * BUFSIZ],
-									      "( Where is your fortune? )\n");
+									      "(Where is your fortune?  This is not good.)");
 								break;
 							case 9:
 								(void) strcat(&buf[screen * BUFSIZ],
-									      "( Your fortune has not been written yet!! )");
+									      "(Your fortune has not been written yet!!)");
+								break;
+							case 10:
+								(void) strcat(&buf[screen * BUFSIZ],
+									      "(Hey, dude when are you going to fix this?)");
+								break;
+							case 11:
+								(void) strcat(&buf[screen * BUFSIZ],
+									      "(Oh, what sad times are these when\none can not get a harmless fortune.)");
 								break;
 						}
 				}
