@@ -89,9 +89,11 @@ static login_cap_t *rlc = NULL;
 
 #include <errno.h>
 #ifndef errno
-extern int  errno;
+extern int errno;
 #endif
 
+extern char error_buf[ERROR_BUF];
+
 #if ( HAVE_FCNTL_H && (defined( USE_MULTIPLE_ROOT ) || defined( USE_MULTIPLE_USER )))
 #include <fcntl.h>
 
@@ -100,7 +102,6 @@ void        set_multiple(int uid);
 
 #define BUFMAX 1024		/* Maximum size of pipe buffer */
 
-
 /* Linked list to keep track of everyone that's authorized * to unlock the
    screen. */
 struct pwln {
@@ -308,15 +309,15 @@ PAM_conv(int num_msg,
 // As a result - abort trap when PAM tries to free reply structure
 // after PAM_ERROR_MSG processing.
 
+	if (!reply)
+		return PAM_BUF_ERR;
+
 // So I just initialize reply here with default values and drop
 // initialization from code below (if code matches).
 
 	reply[replies].resp_retcode = PAM_SUCCESS; // be optimistic
 	reply[replies].resp = NULL;
 
-	if (!reply)
-		return PAM_CONV_ERR;
-
 	for (replies = 0; replies < num_msg; replies++) {
 #ifdef DEBUG
 		(void) printf( "PAM_conv: message of style (%d) received\n", msg[replies]->msg_style );
@@ -496,7 +497,6 @@ int
 checkDynamic()
 {
 	struct passwd *pw;
-	char       *buf;
 
 #ifndef SAFELOG_SWCHECK
 #define SAFELOG_SWCHECK "/progs/safelog/swcheck"
@@ -508,11 +508,10 @@ checkDynamic()
 
 	if (!(pw = my_passwd_entry())) {
 		/*if ((pw = (struct passwd *) getpwuid(getuid())) == NULL) */
-		buf = (char *) malloc(strlen(ProgramName) + 80);
-		(void) sprintf(buf,
-			     "%s: could not get user shell.\n", ProgramName);
-		error(buf);
-		free(buf);	/* Should never get here */
+		(void) sprintf(error_buf, "%s: could not get user shell.\n",
+			(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+			ProgramName : DEFAULT_NAME);
+		error(error_buf);
 	}
 	return (!(strcmp(pw->pw_shell, SAFELOG_SWCHECK) &&
 		  strcmp(pw->pw_shell, SAFELOG_IDENT)));
@@ -541,7 +540,6 @@ getUserName(void)
 	struct passwd *pw;
 	int         pipefd[2], n, total = 0, stat_loc;
 	pid_t       pid;
-	char       *buf;
 
 	pipe(pipefd);
 
@@ -553,11 +551,11 @@ getUserName(void)
 		_exit(0);
 	}
 	if (pid < 0) {
-		buf = (char *) malloc(strlen(ProgramName) + 80);
-		(void) sprintf(buf,
-			       "%s: could not get user password (fork failed)\n", ProgramName);
-		error(buf);
-		free(buf);	/* Should never get here */
+		(void) sprintf(error_buf,
+			"%s: could not get user password (fork failed)\n",
+			(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+			ProgramName : DEFAULT_NAME);
+		error(error_buf);
 	}
 	(void) close(pipefd[1]);
 
@@ -567,39 +565,36 @@ getUserName(void)
 	wait(&stat_loc);
 
 	if (n < 0) {
-		buf = (char *) malloc(strlen(ProgramName) + 80);
-		(void) sprintf(buf,
-		 "%s: could not get user name (read failed)\n", ProgramName);
-		error(buf);
-		free(buf);	/* Should never get here */
+		(void) sprintf(error_buf,
+			"%s: could not get user name (read failed)\n",
+			(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+			ProgramName : DEFAULT_NAME);
+		error(error_buf);
 	}
 	user[total] = 0;
 
 	if (total < 1) {
-		buf = (char *) malloc(strlen(ProgramName) + 80);
-		(void) sprintf(buf,
-			       "%s: could not get user name (lookups failed)\n", ProgramName);
-		error(buf);
-		free(buf);	/* Should never get here */
+		(void) sprintf(error_buf,
+			"%s: could not get user name (lookups failed)\n",
+			(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+			ProgramName : DEFAULT_NAME);
+		error(error_buf);
 	}
 #else /* !HP_PASSWDETC */
 #ifdef OSF1_ENH_SEC
 	struct pr_passwd *pw;
-	char       *buf;
 
 	/*if ((pw = getprpwuid(getuid())) == NULL) */
 	if ((pw = getprpwuid(starting_ruid())) == NULL) {
-		buf = (char *) malloc(strlen(ProgramName) + 80);
-		(void) sprintf(buf,
-			       "%s: could not get user name.\n", ProgramName);
-		error(buf);
-		free(buf);	/* Should never get here */
+		(void) sprintf(error_buf, "%s: could not get user name.\n",
+			(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+			ProgramName : DEFAULT_NAME);
+		error(error_buf);
 	}
 	(void) strcpy(user, pw->ufld.fd_name);
 #else /* !OSF1_ENH_SEC */
 
 	struct passwd *pw;
-	char       *buf;
 
 #ifdef HAVE_KRB5
 	krb5_context context;
@@ -648,11 +643,10 @@ getUserName(void)
 #endif /* HAVE_KRB5 */
 	if (!(pw = my_passwd_entry())) {
 		/*if ((pw = (struct passwd *) getpwuid(getuid())) == NULL) */
-		buf = (char *) malloc(strlen(ProgramName) + 80);
-		(void) sprintf(buf,
-			       "%s: could not get user name.\n", ProgramName);
-		error(buf);
-		free(buf);	/* Should never get here */
+		(void) sprintf(error_buf, "%s: could not get user name.\n",
+			(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+			ProgramName : DEFAULT_NAME);
+		error(error_buf);
 	}
 	(void) strcpy(user, pw->pw_name);
 
@@ -712,12 +706,12 @@ gpass(void)
 			struct passwd *p = my_passwd_entry();
 
 			if (p == 0) {
-				char       *buf = (char *) malloc(strlen(ProgramName) + 80);
-
-				(void) sprintf(buf,
-					  "%s: Who are you?\n", ProgramName);
-				error(buf);
-				free(buf);	/* Should never get here */
+				(void) sprintf(error_buf,
+					"%s: Who are you?\n",
+					(strlen(ProgramName) >
+					ERROR_BUF - ERROR_LINE) ?
+					ProgramName : DEFAULT_NAME);
+				error(error_buf);
 			}
 			home = p->pw_dir;
 		}
@@ -828,7 +822,6 @@ getCryptedUserPasswd(void)
 	struct passwd *pw;
 	int         pipefd[2], n, total = 0, stat_loc;
 	pid_t       pid;
-	char       *buf;
 
 	pipe(pipefd);
 
@@ -840,11 +833,11 @@ getCryptedUserPasswd(void)
 		_exit(0);
 	}
 	if (pid < 0) {
-		buf = (char *) malloc(strlen(ProgramName) + 80);
-		(void) sprintf(buf,
-			       "%s: could not get user password (fork failed)\n", ProgramName);
-		error(buf);
-		free(buf);	/* Should never get here */
+		(void) sprintf(error_buf,
+			"%s: could not get user password (fork failed)\n",
+			(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+			ProgramName : DEFAULT_NAME);
+		error(error_buf);
 	}
 	(void) close(pipefd[1]);
 
@@ -854,33 +847,32 @@ getCryptedUserPasswd(void)
 	wait(&stat_loc);
 
 	if (n < 0) {
-		buf = (char *) malloc(strlen(ProgramName) + 80);
-		(void) sprintf(buf,
-			       "%s: could not get user password (read failed)\n", ProgramName);
-		error(buf);
-		free(buf);	/* Should never get here */
+		(void) sprintf(error_buf,
+			"%s: could not get user password (read failed)\n",
+			(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+			ProgramName : DEFAULT_NAME);
+		error(error_buf);
 	}
 	user[total] = 0;
 
 	if (total < 1) {
-		buf = (char *) malloc(strlen(ProgramName) + 80);
-		(void) sprintf(buf,
-			       "%s: could not get user password (lookups failed)\n", ProgramName);
-		error(buf);
-		free(buf);	/* Should never get here */
+		(void) sprintf(error_buf,
+			"%s: could not get user password (lookups failed)\n",
+			(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+			ProgramName : DEFAULT_NAME);
+		error(error_buf);
 	}
 #else /* !HP_PASSWDETC */
 #ifdef OSF1_ENH_SEC
 	struct pr_passwd *pw;
-	char       *buf;
 
 	/*if ((pw = getprpwuid(getuid())) == NULL) */
 	if ((pw = getprpwuid(starting_ruid())) == NULL) {
-		buf = (char *) malloc(strlen(ProgramName) + 80);
-		(void) sprintf(buf,
-		"%s: could not get encrypted user password.\n", ProgramName);
-		error(buf);
-		free(buf);	/* Should never get here */
+		(void) sprintf(error_buf,
+			"%s: could not get encrypted user password.\n",
+			(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+			ProgramName : DEFAULT_NAME);
+		error(error_buf);
 	}
 	(void) strcpy(userpass, pw->ufld.fd_encrypt);
 	/* also save encryption algorithm associated with encrypted password */
@@ -888,14 +880,13 @@ getCryptedUserPasswd(void)
 #else /* !OSF1_ENH_SEC */
 
 	struct passwd *pw;
-	char       *buf;
 
 	if (!(pw = my_passwd_entry())) {
-		buf = (char *) malloc(strlen(ProgramName) + 80);
-		(void) sprintf(buf,
-		"%s: could not get encrypted user password.\n", ProgramName);
-		error(buf);
-		free(buf);	/* Should never get here */
+		(void) sprintf(error_buf,
+			"%s: could not get encrypted user password.\n",
+			(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+			ProgramName : DEFAULT_NAME);
+		error(error_buf);
 	}
 	/*if ((pw = (struct passwd *) getpwuid(getuid())) == NULL) */
 	/* Check if there is any chance of unlocking the display later...  */
@@ -904,11 +895,10 @@ getCryptedUserPasswd(void)
 #ifdef HAVE_SHADOW
 #if !defined ( AFS ) && !defined ( SIA )
 	if (passwd_invalid(pw->pw_passwd)) {
-		buf = (char *) malloc(strlen(ProgramName) + 80);
 		if (verbose || debug) {
 			(void) fprintf(stderr,
-			  "%s: it looks like you have shadow passwording.\n",
-				       ProgramName);
+				"%s: it looks like you have shadow passwording.\n",
+				ProgramName);
 			(void) fprintf(stderr, "Contact your administrator to setgid or\n");
 			(void) fprintf(stderr, "setuid %s for /etc/shadow read access.\n",
 				       ProgramName);
@@ -971,7 +961,6 @@ getCryptedRootPasswd(void)
 	struct passwd *pw;
 	int         pipefd[2], n, total = 0, stat_loc;
 	pid_t       pid;
-	char       *buf;
 
 	pipe(pipefd);
 
@@ -983,11 +972,11 @@ getCryptedRootPasswd(void)
 		_exit(0);
 	}
 	if (pid < 0) {
-		buf = (char *) malloc(strlen(ProgramName) + 80);
-		(void) sprintf(buf,
-			       "%s: could not get root password (fork failed)\n", ProgramName);
-		error(buf);
-		free(buf);	/* Should never get here */
+		(void) sprintf(error_buf,
+			"%s: could not get root password (fork failed)\n",
+			(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+			ProgramName : DEFAULT_NAME);
+		error(error_buf);
 	}
 	(void) close(pipefd[1]);
 
@@ -997,39 +986,37 @@ getCryptedRootPasswd(void)
 	wait(&stat_loc);
 
 	if (n < 0) {
-		buf = (char *) malloc(strlen(ProgramName) + 80);
-		(void) sprintf(buf,
-			       "%s: could not get root password (read failed)\n", ProgramName);
-		error(buf);
-		free(buf);	/* Should never get here */
+		(void) sprintf(error_buf,
+			"%s: could not get root password (read failed)\n",
+			(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+			ProgramName : DEFAULT_NAME);
+		error(error_buf);
 	}
 	rootpass[total] = 0;
 
 	if (total < 1) {
-		buf = (char *) malloc(strlen(ProgramName) + 80);
-		(void) sprintf(buf,
-			       "%s: could not get root password (lookups failed)\n", ProgramName);
-		error(buf);
-		free(buf);	/* Should never get here */
+		(void) sprintf(error_buf,
+			"%s: could not get root password (lookups failed)\n",
+			(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+			ProgramName : DEFAULT_NAME);
+		error(error_buf);
 	}
 #else /* !HP_PASSWDETC */
 #ifdef OSF1_ENH_SEC
 	struct pr_passwd *pw;
-	char       *buf;
 
 	if ((pw = getprpwnam(ROOT)) == NULL) {
-		buf = (char *) malloc(strlen(ProgramName) + 80);
-		(void) sprintf(buf,
-		"%s: could not get encrypted root password.\n", ProgramName);
-		error(buf);
-		free(buf);	/* Should never get here */
+		(void) sprintf(error_buf,
+			"%s: could not get encrypted root password.\n",
+			(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+			ProgramName : DEFAULT_NAME);
+		error(error_buf);
 	}
 	(void) strcpy(rootpass, pw->ufld.fd_encrypt);
 	/* also save encryption algorithm associated with encrypted password */
 	root_oldcrypt = pw->ufld.fd_oldcrypt;
 #else /* !OSF1_ENH_SEC */
 	struct passwd *pw;
-	char       *buf;
 
 #ifdef HAVE_SHADOW
 	struct spwd *spw;
@@ -1039,11 +1026,11 @@ getCryptedRootPasswd(void)
 	if (!(pw = getpwnam(ROOT)))
 		if (!(pw = getpwuid(0))) {
 			/*if ((pw = (struct passwd *) getpwuid(0)) == NULL) */
-			buf = (char *) malloc(strlen(ProgramName) + 80);
-			(void) sprintf(buf,
-				       "%s: could not get encrypted root password.\n", ProgramName);
-			error(buf);
-			free(buf);	/* Should never get here */
+			(void) sprintf(error_buf,
+				"%s: could not get encrypted root password.\n",
+				(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+				ProgramName : DEFAULT_NAME);
+			error(error_buf);
 		}
 #ifdef HAVE_SHADOW
 /*-
@@ -1174,10 +1161,10 @@ checkPasswd(char *buffer)
  * Query: should we be using PAM_SILENT to shut PAM up?
  */
 	pam_handle_t *pamh;
-	int         pam_error;
+	int pam_error;
 	char *display;
 #ifdef BAD_PAM
-	uid_t       ruid;
+	uid_t ruid;
 #define BAD_PAM_SETUID	seteuid(ruid);
 #else
 #define BAD_PAM_SETUID
@@ -1194,7 +1181,7 @@ checkPasswd(char *buffer)
 	(void) printf("PAM: Before: UID (%d), EUID (%d)\n", getuid(), geteuid());
 #endif
 	PAM_password = buffer;
-	pam_error = pam_start("xlock", user, &PAM_conversation, &pamh);
+	pam_error = pam_start(DEFAULT_NAME, user, &PAM_conversation, &pamh);
 	PAM_BAIL;
 
 	display = getenv("DISPLAY");
@@ -1253,10 +1240,10 @@ checkPasswd(char *buffer)
 #endif
 #endif
 	done = ((authenticate_user((struct passwd *) getpwnam(user),
-				   buffer, NULL) >= 0);
+		buffer, NULL) >= 0);
 	if (!done && allowroot &&
-		 (authenticate_user((struct passwd *) getpwnam(ROOT),
-					    buffer, NULL) >= 0))) {
+			(authenticate_user((struct passwd *) getpwnam(ROOT),
+			buffer, NULL) >= 0))) {
 		done = True;
 		if (!*buffer)
 			/*
@@ -1349,7 +1336,7 @@ checkPasswd(char *buffer)
 #endif /* AFS */
 #ifdef SIA
 	{
-		if ((sia_validate_user(NULL, "xlock", 1, NULL, user, NULL,
+		if ((sia_validate_user(NULL, DEFAULT_NAME, 1, NULL, user, NULL,
 				0, NULL, buffer)) == SIASUCCESS)
 			return True;
 	}
@@ -1477,8 +1464,6 @@ initDCE(void)
 	struct userpw *userpwd;
 
 #endif
-	char       *buf;
-
 	/* test to see if this user exists on the network registry */
 	valid = sec_login_setup_identity((unsigned_char_p_t) user,
 			  sec_login_no_flags, &login_context, &error_status);
@@ -1491,11 +1476,11 @@ initDCE(void)
 					       ProgramName);
 				break;
 			case sec_login_s_no_memory:
-				buf = (char *) malloc(strlen(ProgramName) + 80);
-				(void) sprintf(buf,
-					 "%s: out of memory\n", ProgramName);
-				error(buf);
-				free(buf);	/* Should never get here */
+				(void) sprintf(error_buf,
+					"%s: out of memory\n",
+					(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+					ProgramName : DEFAULT_NAME);
+				error(error_buf);
 			default:
 				(void) fprintf(stderr,
 					       "%s: sec_login_setup_identity() returned status %d\n",
@@ -1505,11 +1490,11 @@ initDCE(void)
 
 		pwd = getpwnam(user);
 		if (!pwd || strlen(pwd->pw_passwd) < 10) {
-			buf = (char *) malloc(strlen(ProgramName) + 80);
-			(void) sprintf(buf,
-			   "%s: could not get user password\n", ProgramName);
-			error(buf);
-			free(buf);	/* Should never get here */
+			(void) sprintf(error_buf,
+				"%s: could not get user password\n",
+				(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+				ProgramName : DEFAULT_NAME);
+			error(error_buf);
 		}
 		usernet = 0;
 		(void) strcpy(userpass, pwd->pw_passwd);
@@ -1538,22 +1523,23 @@ initDCE(void)
 						       ProgramName);
 					break;
 				case sec_login_s_no_memory:
-					buf = (char *) malloc(strlen(ProgramName) + 80);
-					(void) sprintf(buf,
-					 "%s: out of memory\n", ProgramName);
-					error(buf);
-					free(buf);	/* Should never get here */
+					(void) sprintf(error_buf,
+						"%s: out of memory\n",
+						(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+						ProgramName : DEFAULT_NAME);
+					error(error_buf);
 				default:
 					(void) fprintf(stderr,
-						       "%s: sec_login_setup_identity() returned status %d\n",
-					    ProgramName, (int) error_status);
+					       "%s: sec_login_setup_identity() returned status %d\n",
+						ProgramName, (int) error_status);
 					break;
 			}
 
 			pwd = getpwuid(0);
 			if (!pwd || strlen(pwd->pw_passwd) < 10) {
 				(void) fprintf(stderr,
-					       "%s: could not get root password\n", ProgramName);
+					"%s: could not get root password\n",
+					ProgramName);
 				allowroot = 0;
 			}
 			rootnet = 0;
@@ -1822,12 +1808,12 @@ krb_check_password(char *user, char *pass)
 	 */
 
 	option = 0;
-	krb5_appdefault_boolean(kcontext, "xlock",
+	krb5_appdefault_boolean(kcontext, DEFAULT_NAME,
 				krb5_princ_realm(context, me), "forwardable",
 				option, &option);
 	krb5_get_init_creds_opt_set_forwardable(&options, option);
 
-	krb5_appdefault_string(kcontext, "xlock", krb5_princ_realm(context, me),
+	krb5_appdefault_string(kcontext, DEFAULT_NAME, krb5_princ_realm(context, me),
 			       "default_lifetime", "", &lifetimestr);
 
 	if (lifetimestr && *lifetimestr) {
@@ -2199,7 +2185,7 @@ initPasswd(void)
 */
 
 #ifndef GROUP
-#define GROUP "xlock"
+#define GROUP DEFAULT_NAME
 #endif
 
 #define PASSLENGTH1 (PASSLENGTH+1)
@@ -2321,7 +2307,7 @@ run_helper(const char *user, const char *pass)
       dup2(pfd[0], 0);
 
     /* Helper is invoked as helper service-name [user] */
-    execlp(PASSWD_HELPER_PROGRAM, PASSWD_HELPER_PROGRAM,"xlock", user, NULL);
+    execlp(PASSWD_HELPER_PROGRAM, PASSWD_HELPER_PROGRAM, DEFAULT_NAME, user, NULL);
     error("Failed to execute " PASSWD_HELPER_PROGRAM);
     exit(1);
   }
