@@ -309,6 +309,7 @@ static char *modeclassname;
 extern Window parent;
 static char *parentname;
 extern Bool parentSet;
+extern char error_buf[ERROR_BUF];
 
 #if HAVE_DIRENT_H
 static struct dirent ***images_list = (struct dirent ***) NULL;
@@ -1237,12 +1238,11 @@ GetResource(XrmDatabase database,
 				char       *s = (char *) malloc(len + 1);
 
 				if (s == (char *) NULL) {
-					char       *buf = (char *) malloc(strlen(ProgramName) + 80);
-
-					(void) sprintf(buf,
-						       "%s: GetResource - could not allocate memory", ProgramName);
-					error(buf);
-					free(buf);	/* Should never get here */
+					(void) sprintf(error_buf,
+						"%s: GetResource - could not allocate memory",
+						(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+						ProgramName : DEFAULT_NAME);
+					error(error_buf);
 				}
 				(void) strncpy(s, string, len);
 				s[len] = '\0';
@@ -1465,13 +1465,18 @@ openDisplay(Display ** displayp)
 /* PURIFY 4.0.1 on Solaris 2 reports an uninitialized memory read on the next
  * the following line. */
 	if (!(*displayp = XOpenDisplay((displayname) ? displayname : ""))) {
-		buf = (char *) malloc(strlen(ProgramName) +
-			     ((displayname) ? strlen(displayname) : 0) + 80);
-		(void) sprintf(buf,
-			     "%s: unable to open display %s.\n", ProgramName,
-			       ((displayname) ? displayname : ""));
-		error(buf);
-		free(buf);	/* Should never get here */
+		int pnl = strlen(ProgramName);
+		int dnl = (displayname) ? strlen(displayname) : 0;
+
+		pnl = (pnl < ERROR_BUF - ERROR_LINE) ? pnl :
+			strlen(DEFAULT_NAME);
+		(void) sprintf(error_buf,
+			"%s: unable to open display %s.\n",
+			((strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+			ProgramName : DEFAULT_NAME),
+			(dnl + pnl < ERROR_BUF - ERROR_LINE) ?
+			((displayname) ? displayname : "") : "");
+		error(error_buf);
 	}
 	displayname = DisplayString(*displayp);
 }
@@ -1526,11 +1531,11 @@ checkDisplay(void)
 	    {
 #endif
 
-		buf = (char *) malloc(strlen(ProgramName) + 80);
-		(void) sprintf(buf,
-			   "%s: Can not get local hostname.\n", ProgramName);
-		error(buf);
-		free(buf);	/* Should never get here */
+		(void) sprintf(error_buf,
+			"%s: Can not get local hostname.\n",
+			(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+			ProgramName : DEFAULT_NAME);
+		error(error_buf);
 	}
 #ifdef VMS
 	}
@@ -1555,13 +1560,21 @@ checkDisplay(void)
 				exit(status);
 
 			if (strcmp(server_transport, "LOCAL")) {
+				int pnl = strlen(ProgramName);
+				int dnl = (displayname) ?
+					strlen(displayname) : 0;
+
 				(void) strcat(displayname, "'s display via ");
 				(void) strncat(displayname, server_transport, len);
-				buf = (char *) malloc(strlen(ProgramName) + strlen(displayname) + 80);
-				(void) sprintf(buf,
-					       "%s: can not lock %s\n", ProgramName, displayname);
-				error(buf);
-				free(buf);	/* Should never get here */
+				pnl = (pnl < ERROR_BUF - ERROR_LINE) ?
+					pnl : strlen(DEFAULT_NAME);
+				(void) sprintf(error_buf,
+					"%s: can not lock %s\n",
+					(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+					ProgramName : DEFAULT_NAME,
+					(dnl + pnl < ERROR_BUF - ERROR_LINE) ?
+					((displayname) ? displayname : "") : "");
+				error(error_buf);
 			}
 		}
 	} else {
@@ -1572,13 +1585,19 @@ checkDisplay(void)
 			int         n = colon - displayname;
 
 			if (colon == NULL) {
-				buf = (char *) malloc(strlen(ProgramName) +
-						   strlen(displayname) + 80);
-				(void) sprintf(buf,
-				 "%s: Malformed -display argument, \"%s\"\n",
-					       ProgramName, displayname);
-				error(buf);
-				free(buf);	/* Should never get here */
+				int pnl = strlen(ProgramName);
+				int dnl = (displayname) ?
+					strlen(displayname) : 0;
+
+				pnl = (pnl < ERROR_BUF - ERROR_LINE) ?
+					pnl : strlen(DEFAULT_NAME);
+				(void) sprintf(error_buf,
+					"%s: Malformed -display argument, \"%s\"\n",
+					(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+					ProgramName : DEFAULT_NAME,
+					(dnl + pnl < ERROR_BUF - ERROR_LINE) ?
+					((displayname) ? displayname : "") : "");
+				error(error_buf);
 			}
 			if (!remote && n
 			    && strncmp(displayname, "unix", n)
@@ -1601,14 +1620,23 @@ checkDisplay(void)
 						}
 					}
 					if (badhost) {
+						int pnl = strlen(ProgramName);
+						int dnl = (displayname) ?
+							strlen(displayname) : 0;
+
 						*colon = (char) 0;
-						buf = (char *) malloc(strlen(ProgramName) +
-						   strlen(displayname) + 80);
-						(void) sprintf(buf,
-							       "%s: can not lock %s's display\n",
-						   ProgramName, displayname);
-						error(buf);
-						free(buf);	/* Should never get here */
+						error(error_buf);
+
+						pnl = (pnl < ERROR_BUF - ERROR_LINE) ?
+							pnl : strlen(DEFAULT_NAME);
+						(void) sprintf(error_buf,
+							"%s: can not lock %s's display\n",
+							(strlen(ProgramName) < ERROR_BUF - ERROR_LINE) ?
+							ProgramName : DEFAULT_NAME,
+							(dnl + pnl <
+							ERROR_BUF - ERROR_LINE) ?
+							((displayname) ? displayname : "") : "");
+						error(error_buf);
 					}
 				}
 			}
@@ -1828,8 +1856,8 @@ getResources(Display ** displayp, int argc, char **argv)
 	ProgramName = stripname(ProgramName);
 #endif
 	XrmParseCommand(&earlyCmdlineDB, earlyCmdlineTable,
-			earlyCmdlineEntries, "xlock", &argc, argv);
-	GetResource(earlyCmdlineDB, "xlock", classname, "name", "Name",
+			earlyCmdlineEntries, DEFAULT_NAME, &argc, argv);
+	GetResource(earlyCmdlineDB, DEFAULT_NAME, classname, "name", "Name",
 		    t_String, ProgramName, &ProgramName);
 #ifdef CUSTOMIZATION
 	GetResource(earlyCmdlineDB, ProgramName, classname, "display",
