@@ -18,6 +18,7 @@ static const char sccsid[] = "@(#)visgl.c	5.01 01/02/19 xlockmore";
 
 
 #include "xlock.h"
+#include "vis.h"
 #include "visgl.h"
 
 #ifdef USE_GL
@@ -94,6 +95,7 @@ init_GL(ModeInfo * mi)
 	XVisualInfo xvi_in, *xvi_out;
 	int         num_vis;
 	GLboolean   rgbaMode;
+	Colormap cmap;
 
 #ifdef FX
 	extern void resetSize(ModeInfo * mi, Bool setGL);
@@ -118,16 +120,70 @@ init_GL(ModeInfo * mi)
 		(void) fprintf(stderr, "Could not get XVisualInfo\n");
 		return (GLXContext *) NULL;
 	}
+   
+	if ( xvi_out->CLASS == DirectColor ) {
+		XColor xc[256];
+		int maxColors = 256, i;
+		int bits0 = 8, bits1 = 8, bits2 = 8;
+
+		cmap = XCreateColormap(display, window, MI_VISUAL(mi),
+			AllocAll);
+		if (xvi_out->depth < 24) {
+			maxColors = 8;
+			bits0 = 2, bits1 = 3, bits2 = 3;
+		}
+		/* init the red, green, blue maps to linear ramps */
+
+		for (i = 0; i < maxColors; i++) {
+			xc[i].pixel = (i << (bits0 + bits1)) | (i << bits0) | i;
+			xc[i].red = (i << bits2) | i;
+			xc[i].green = (i << bits1) | i;
+			xc[i].blue = (i << bits0) | i;
+			xc[i].flags = DoRed | DoGreen | DoBlue;
+		}
+#ifndef NO_RESERVE_BLACK
+		i = 0;
+		xc[i].pixel = MI_BLACK_PIXEL(mi);
+		xc[i].red = 0;
+		xc[i].green = 0;
+		xc[i].blue = 0;
+#endif
+#ifndef NO_RESERVE_WHITE
+		i = 1;
+		/* i = maxColors - 1; */
+		xc[i].pixel = MI_WHITE_PIXEL(mi);
+		xc[i].red = 0xFFFF;
+		xc[i].green = 0xFFFF;
+		xc[i].blue = 0xFFFF;
+#endif
+		XStoreColors(display, cmap, xc, maxColors);
+		XInstallColormap(display, cmap);
+	}
+   
+	if (glOK && glOK[screen]) {
+#ifdef SUN_OGL_NO_VERTEX_MACROS
+/* Cores when run in GrayScale|StaticGray|StaticColor on OpenGL Solaris 10 */
+		if (xvi_out->CLASS == StaticGray ||
+				xvi_out->CLASS == GrayScale ||
+				xvi_out->CLASS == StaticColor) {
+			XFree((char *) xvi_out);
+			if (MI_IS_VERBOSE(mi))
+				(void) fprintf(stderr,
+				       "Avoiding possible problem of using glxCreateContext with %s on screen %d.\n",
+					nameOfVisualClass(xvi_out->CLASS),
+					screen);
+			return (GLXContext *) NULL;
+		}
+#endif
 /*-
  * PURIFY 4.0.1 on SunOS4 and on Solaris 2 reports a 104 byte memory leak on
  * the next line each time that a GL mode is run in random mode when using
  * MesaGL 2.2.  This cumulative leak can cause xlock to eventually crash if
  * available memory is depleted.  This bug is fixed in MesaGL 2.3. */
-	if (glOK && glOK[screen])
-		glXContext[screen] = glXCreateContext(display, xvi_out, 0, GL_TRUE);
-
+		glXContext[screen] = glXCreateContext(display, xvi_out,
+			0, GL_TRUE);
+	}
 	XFree((char *) xvi_out);
-
 	if (!glXContext[screen]) {
 		if (MI_IS_VERBOSE(mi))
 			(void) fprintf(stderr,
