@@ -253,9 +253,11 @@ XrmOptionDescRec options[100];
 #endif
 #endif
 #ifndef TEXTLINES
-#define TEXTLINES      40
+#define TEXTLINES 40
 #endif
-#define PASSLENGTH        120
+#define PASSLENGTH 120
+#define ERROR_BUF 2048
+#define ERROR_LINE 80
 
 #ifdef HAVE_SYS_PARAM_H
 #include <sys/param.h>
@@ -606,4 +608,6 @@ void xlockmore_win32_text(int xloc, int yloc, char *text);
 void xlockmore_set_debug(char *text);
 #endif
 
+#define DEFAULT_NAME "xlock"
+
 #endif /* __XLOCK_XLOCK_H__ */
